@@ -1,20 +1,24 @@
 /*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 1999 - 2009 The GNOME Foundation
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This program is distributed in the hope that it will be useful,
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -173,7 +177,7 @@ gdaui_dsn_editor_init (GdauiDsnEditor *config, G_GNUC_UNUSED GdauiDsnEditorClass
 	g_signal_connect (G_OBJECT (config->priv->wprovider), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wprovider, 1, 2, 2, 3,
-			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, 0, 0, 0);
 
 	label = gtk_label_new_with_mnemonic (_("_Description:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, -1.);
@@ -326,7 +330,7 @@ gdaui_dsn_editor_get_dsn (GdauiDsnEditor *config)
 /**
  * gdaui_dsn_editor_set_dsn
  * @editor: a #GdauiDsnEditor widget
- * @dsn_info: (allow-none): a #GdaDsnInfo pointer or %NULL
+ * @dsn_info: a #GdaDsnInfo pointer or %NULL
  *
  *
  * Requests that @editor update its contents with @dsn_info's contents
