@@ -1,21 +1,21 @@
-/*
+/* gdaui-data-cell-renderer-bin.c
+ *
  * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <stdlib.h>
@@ -41,15 +41,14 @@ static void gdaui_data_cell_renderer_bin_class_init (GdauiDataCellRendererBinCla
 static void gdaui_data_cell_renderer_bin_dispose    (GObject *object);
 static void gdaui_data_cell_renderer_bin_finalize   (GObject *object);
 static void gdaui_data_cell_renderer_bin_render     (GtkCellRenderer            *cell,
-						     GdkWindow                  *window,
+						     cairo_t                    *cr,
 						     GtkWidget                  *widget,
-						     GdkRectangle               *background_area,
-						     GdkRectangle               *cell_area,
-						     GdkRectangle               *expose_area,
+						     const GdkRectangle         *background_area,
+						     const GdkRectangle         *cell_area,
 						     GtkCellRendererState        flags);
 static void gdaui_data_cell_renderer_bin_get_size   (GtkCellRenderer            *cell,
 						     GtkWidget                  *widget,
-						     GdkRectangle               *cell_area,
+						     const GdkRectangle         *cell_area,
 						     gint                       *x_offset,
 						     gint                       *y_offset,
 						     gint                       *width,
@@ -58,8 +57,8 @@ static gboolean gdaui_data_cell_renderer_bin_activate  (GtkCellRenderer
 							GdkEvent                   *event,
 							GtkWidget                  *widget,
 							const gchar                *path,
-							GdkRectangle               *background_area,
-							GdkRectangle               *cell_area,
+							const GdkRectangle         *background_area,
+							const GdkRectangle         *cell_area,
 							GtkCellRendererState        flags);
 
 enum {
@@ -328,7 +327,7 @@ gdaui_data_cell_renderer_bin_set_property (GObject *object,
  * in the model, thus causing the check button to reflect the state of
  * the model.
  * 
- * Returns: (transfer full): the new cell renderer
+ * Return value: (transfer full): the new cell renderer
  */
 GtkCellRenderer *
 gdaui_data_cell_renderer_bin_new (GdaDataHandler *dh, GType type)
@@ -346,7 +345,7 @@ gdaui_data_cell_renderer_bin_new (GdaDataHandler *dh, GType type)
 static void
 gdaui_data_cell_renderer_bin_get_size (GtkCellRenderer *cell,
 				       GtkWidget       *widget,
-				       GdkRectangle    *cell_area,
+				       const GdkRectangle *cell_area,
 				       gint            *x_offset,
 				       gint            *y_offset,
 				       gint            *width,
@@ -359,17 +358,16 @@ gdaui_data_cell_renderer_bin_get_size (GtkCellRenderer *cell,
 
 static void
 gdaui_data_cell_renderer_bin_render (GtkCellRenderer      *cell,
-				     GdkWindow            *window,
+				     cairo_t              *cr,
 				     GtkWidget            *widget,
-				     GdkRectangle         *background_area,
-				     GdkRectangle         *cell_area,
-				     GdkRectangle         *expose_area,
+				     const GdkRectangle   *background_area,
+				     const GdkRectangle   *cell_area,
 				     GtkCellRendererState  flags)
 {
 	GdauiDataCellRendererBin *datacell = (GdauiDataCellRendererBin*) cell;
 	GtkCellRendererClass *pixbuf_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_PIXBUF);
 
-	(pixbuf_class->render) (cell, window, widget, background_area, cell_area, expose_area, flags);
+	(pixbuf_class->render) (cell, cr, widget, background_area, cell_area, flags);
 	
 	if (datacell->priv->to_be_deleted) {
 		GtkStyle *style;
@@ -379,8 +377,7 @@ gdaui_data_cell_renderer_bin_render (GtkCellRenderer      *cell,
 		g_object_get ((GObject*) cell, "xpad", &xpad, NULL);
 
 		gtk_paint_hline (style,
-				 window, GTK_STATE_SELECTED,
-				 cell_area, 
+				 cr, GTK_STATE_SELECTED,
 				 widget,
 				 "hline",
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
@@ -388,7 +385,7 @@ gdaui_data_cell_renderer_bin_render (GtkCellRenderer      *cell,
 		g_object_unref (style);
 	}
 	if (datacell->priv->invalid)
-		gdaui_data_cell_renderer_draw_invalid_area (window, cell_area);
+		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
 }
 
 static void
@@ -439,9 +436,9 @@ gdaui_data_cell_renderer_bin_activate  (GtkCellRenderer            *cell,
 					GdkEvent                   *event,
 					GtkWidget                  *widget,
 					const gchar                *path,
-					G_GNUC_UNUSED GdkRectangle               *background_area,
-					GdkRectangle               *cell_area,
-					G_GNUC_UNUSED GtkCellRendererState        flags)
+					G_GNUC_UNUSED const GdkRectangle *background_area,
+					const GdkRectangle         *cell_area,
+					G_GNUC_UNUSED GtkCellRendererState flags)
 {
 	GdauiDataCellRendererBin *bincell;
 	GtkTreeModel *model;
@@ -470,7 +467,7 @@ gdaui_data_cell_renderer_bin_activate  (GtkCellRenderer            *cell,
 		common_bin_adjust_menu (&(bincell->priv->menu), bincell->priv->editable,
 					value);
 		g_object_set_data (G_OBJECT (bincell->priv->menu.popup), "__event", event);
-		g_object_set_data (G_OBJECT (bincell->priv->menu.popup), "__rect", (GdkRectangle*)cell_area);
+		g_object_set_data (G_OBJECT (bincell->priv->menu.popup), "__rect", cell_area);
 		gtk_widget_show (bincell->priv->menu.popup);
 	}
 	gtk_tree_path_free (tpath);
