@@ -1,21 +1,22 @@
-/*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* gdaui-data-cell-renderer-combo.c
+ *
+ * Copyright (C) 2000  Red Hat, Inc.,  Jonathan Blandford <jrb@redhat.com>
+ * Copyright (C) 2003 - 2010 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <stdlib.h>
@@ -46,25 +47,24 @@ static void gdaui_data_cell_renderer_combo_set_property  (GObject *object,
 							  GParamSpec *pspec);
 static void gdaui_data_cell_renderer_combo_get_size   (GtkCellRenderer          *cell,
 						       GtkWidget                *widget,
-						       GdkRectangle             *cell_area,
+						       const GdkRectangle       *cell_area,
 						       gint                     *x_offset,
 						       gint                     *y_offset,
 						       gint                     *width,
 						       gint                     *height);
 static void gdaui_data_cell_renderer_combo_render     (GtkCellRenderer          *cell,
-						       GdkWindow                *window,
+						       cairo_t                  *cr,
 						       GtkWidget                *widget,
-						       GdkRectangle             *background_area,
-						       GdkRectangle             *cell_area,
-						       GdkRectangle             *expose_area,
+						       const GdkRectangle       *background_area,
+						       const GdkRectangle       *cell_area,
 						       GtkCellRendererState      flags);
 
 static GtkCellEditable *gdaui_data_cell_renderer_combo_start_editing (GtkCellRenderer     *cell,
 								      GdkEvent            *event,
 								      GtkWidget           *widget,
 								      const gchar         *path,
-								      GdkRectangle        *background_area,
-								      GdkRectangle        *cell_area,
+								      const GdkRectangle  *background_area,
+								      const GdkRectangle  *cell_area,
 								      GtkCellRendererState flags);
 
 enum {
@@ -437,7 +437,7 @@ render_text_to_display_from_values (GList *values)
  * Creates a new #GdauiDataCellRendererCombo which will fill the parameters listed in
  * @source->nodes with values available from @source->data_model.
  * 
- * Returns: (transfer full): the new cell renderer
+ * Return value: (transfer full): the new cell renderer
  **/
 GtkCellRenderer *
 gdaui_data_cell_renderer_combo_new (GdauiSet *paramlist, GdauiSetSource *source)
@@ -457,7 +457,7 @@ gdaui_data_cell_renderer_combo_new (GdauiSet *paramlist, GdauiSetSource *source)
 static void
 gdaui_data_cell_renderer_combo_get_size (GtkCellRenderer *cell,
 					 GtkWidget       *widget,
-					 GdkRectangle    *cell_area,
+					 const GdkRectangle *cell_area,
 					 gint            *x_offset,
 					 gint            *y_offset,
 					 gint            *width,
@@ -489,11 +489,10 @@ gdaui_data_cell_renderer_combo_get_size (GtkCellRenderer *cell,
 
 static void
 gdaui_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
-				       GdkWindow            *window,
+				       cairo_t              *cr,
 				       GtkWidget            *widget,
-				       GdkRectangle         *background_area,
-				       GdkRectangle         *cell_area,
-				       GdkRectangle         *expose_area,
+				       const GdkRectangle   *background_area,
+				       const GdkRectangle   *cell_area,
 				       GtkCellRendererState  flags)
 	
 {
@@ -502,7 +501,7 @@ gdaui_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
 
 	/* render the text as for the GtkCellRendererText */
 	GtkCellRendererClass *text_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_TEXT);
-	(text_class->render) (cell, window, widget, background_area, cell_area, expose_area, flags);
+	(text_class->render) (cell, cr, widget, background_area, cell_area, flags);
 
 	/* render the popdown menu symbol */
 	if ((flags & GTK_CELL_RENDERER_SELECTED) == GTK_CELL_RENDERER_SELECTED)	{
@@ -532,8 +531,7 @@ gdaui_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
 		g_object_get ((GObject*) cell, "xpad", &xpad, "ypad", &ypad, NULL);
 		
 		gtk_paint_expander (style,
-				    window, state,
-				    cell_area, 
+				    cr, state,
 				    widget,
 				    "expander",
 				    cell_area->x + cell_area->width - xpad - expander_size/2.,
@@ -550,8 +548,7 @@ gdaui_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
 		g_object_get ((GObject*) cell, "xpad", &xpad, NULL);
 
 		gtk_paint_hline (style,
-				 window, GTK_STATE_SELECTED,
-				 cell_area, 
+				 cr, GTK_STATE_SELECTED,
 				 widget,
 				 "hline",
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
@@ -560,7 +557,7 @@ gdaui_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
 	}
 
 	if (combocell->priv->invalid)
-		gdaui_data_cell_renderer_draw_invalid_area (window, cell_area);
+		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
 }
 
 static void gdaui_data_cell_renderer_combo_editing_done (GtkCellEditable *combo, GdauiDataCellRendererCombo *datacell);
@@ -572,8 +569,8 @@ gdaui_data_cell_renderer_combo_start_editing (GtkCellRenderer     *cell,
 					      G_GNUC_UNUSED GdkEvent            *event,
 					      G_GNUC_UNUSED GtkWidget           *widget,
 					      const gchar         *path,
-					      G_GNUC_UNUSED GdkRectangle        *background_area,
-					      G_GNUC_UNUSED GdkRectangle        *cell_area,
+					      G_GNUC_UNUSED const GdkRectangle        *background_area,
+					      G_GNUC_UNUSED const GdkRectangle        *cell_area,
 					      G_GNUC_UNUSED GtkCellRendererState flags)
 {
 	GdauiDataCellRendererCombo *datacell;
