@@ -141,7 +141,8 @@ gdaui_entry_number_class_init (GdauiEntryNumberClass * klass)
 	object_class->get_property = gdaui_entry_number_get_property;
 
 	g_object_class_install_property (object_class, PROP_EDITING_CANCELED,
-					 g_param_spec_boolean ("editing-canceled", NULL, NULL, FALSE, G_PARAM_READABLE));
+					 g_param_spec_boolean ("editing-canceled", NULL, NULL, FALSE,
+							       G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_OPTIONS,
 					 g_param_spec_string ("options", NULL, NULL, NULL, G_PARAM_WRITABLE));
 }
@@ -149,7 +150,7 @@ gdaui_entry_number_class_init (GdauiEntryNumberClass * klass)
 static gboolean
 key_press_event_cb (GdauiEntryNumber *mgstr, GdkEventKey *key_event, G_GNUC_UNUSED gpointer data)
 {
-	if (key_event->keyval == GDK_Escape)
+	if (key_event->keyval == GDK_KEY_Escape)
 		mgstr->priv->editing_canceled = TRUE;
 	return FALSE;
 }
@@ -250,9 +251,9 @@ gdaui_entry_number_finalize (GObject   * object)
 
 static void
 gdaui_entry_number_set_property (GObject *object,
-				    guint param_id,
-				    const GValue *value,
-				    GParamSpec *pspec)
+				 guint param_id,
+				 const GValue *value,
+				 GParamSpec *pspec)
 {
 	GdauiEntryNumber *mgstr;
 
@@ -262,6 +263,9 @@ gdaui_entry_number_set_property (GObject *object,
 		case PROP_OPTIONS:
 			set_entry_options (mgstr, g_value_get_string (value));
 			break;
+		case PROP_EDITING_CANCELED:
+			TO_IMPLEMENT;
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -271,9 +275,9 @@ gdaui_entry_number_set_property (GObject *object,
 
 static void
 gdaui_entry_number_get_property (GObject *object,
-			     guint param_id,
-			     GValue *value,
-			     GParamSpec *pspec)
+				 guint param_id,
+				 GValue *value,
+				 GParamSpec *pspec)
 {
 	GdauiEntryNumber *mgstr;
 
