@@ -1,5 +1,4 @@
-/* gdaui-entry-string.c
- *
+/*
  * Copyright (C) 2003 - 2011 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
@@ -217,7 +216,6 @@ gdaui_entry_string_new (GdaDataHandler *dh, GType type, const gchar *options)
 	return GTK_WIDGET (obj);
 }
 
-static gboolean focus_out_cb (GtkWidget *widget, GdkEventFocus *event, GdauiEntryString *mgstr);
 static void
 gdaui_entry_string_dispose (GObject   * object)
 {
@@ -228,17 +226,11 @@ gdaui_entry_string_dispose (GObject   * object)
 
 	mgstr = GDAUI_ENTRY_STRING (object);
 	if (mgstr->priv) {
-		if (mgstr->priv->entry) {
-			g_signal_handlers_disconnect_by_func (G_OBJECT (mgstr->priv->entry),
-							      G_CALLBACK (focus_out_cb), mgstr);
+		if (mgstr->priv->entry)
 			mgstr->priv->entry = NULL;
-		}
 		
-		if (mgstr->priv->view) {
-			g_signal_handlers_disconnect_by_func (G_OBJECT (mgstr->priv->view),
-							      G_CALLBACK (focus_out_cb), mgstr);
+		if (mgstr->priv->view)
 			mgstr->priv->view = NULL;
-		}
 	}
 
 	/* parent class */
@@ -462,18 +454,6 @@ real_get_value (GdauiEntryWrapper *mgwrap)
 	return value;
 }
 
-typedef void (*Callback2) (gpointer, gpointer);
-static gboolean
-focus_out_cb (GtkWidget *widget, GdkEventFocus *event, GdauiEntryString *mgstr)
-{
-	GCallback activate_cb;
-	activate_cb = g_object_get_data (G_OBJECT (widget), "_activate_cb");
-	g_assert (activate_cb);
-	((Callback2)activate_cb) (widget, mgstr);
-
-	return gtk_widget_event (GTK_WIDGET (mgstr), (GdkEvent*) event);
-}
-
 static void
 connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb)
 {
@@ -482,20 +462,14 @@ connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activa
 	g_return_if_fail (GDAUI_IS_ENTRY_STRING (mgwrap));
 	mgstr = GDAUI_ENTRY_STRING (mgwrap);
 	g_return_if_fail (mgstr->priv);
-	g_object_set_data (G_OBJECT (mgstr->priv->entry), "_activate_cb", activate_cb);
-	g_object_set_data (G_OBJECT (mgstr->priv->view), "_activate_cb", activate_cb);
 
 	mgstr->priv->entry_change_sig = g_signal_connect (G_OBJECT (mgstr->priv->entry), "changed",
 							  modify_cb, mgwrap);
 	g_signal_connect (G_OBJECT (mgstr->priv->entry), "activate",
 			  activate_cb, mgwrap);
-	g_signal_connect (G_OBJECT (mgstr->priv->entry), "focus-out-event",
-			  G_CALLBACK (focus_out_cb), mgstr);
 
 	g_signal_connect (G_OBJECT (mgstr->priv->buffer), "changed",
 			  modify_cb, mgwrap);
-	g_signal_connect (G_OBJECT (mgstr->priv->view), "focus-out-event",
-			  G_CALLBACK (focus_out_cb), mgstr);
 	/* FIXME: how does the user "activates" the GtkTextView widget ? */
 }
 
