@@ -1,28 +1,26 @@
-/*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+/* common-pict.c
+ * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include "common-pict.h"
 #include <string.h>
 #include <libgda/gda-quark-list.h>
 #include <libgda/gda-blob-op.h>
-#include <libgda-ui/libgda-ui.h>
-#include <libgda-ui/gdaui-data-entry.h>
 
 /*
  * Fills in @bindata->data and @bindata->data_length with the contents of @value.
@@ -38,8 +36,7 @@ common_pict_load_data (PictOptions *options, const GValue *value, PictBinData *b
 	if (value) {
 		if (gda_value_is_null ((GValue *) value)) {
 			*stock = GTK_STOCK_MISSING_IMAGE;
-			g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-				     "%s", _("No data"));
+			g_set_error (error, 0, 0, _("No data"));
 			allok = FALSE;
 		}
 		else {
@@ -70,8 +67,8 @@ common_pict_load_data (PictOptions *options, const GValue *value, PictBinData *b
 				}
 				else {
 					*stock = GTK_STOCK_DIALOG_ERROR;
-					g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-						     "%s", _("No data"));
+					g_set_error (error, 0, 0,
+						     _("No data"));
 					allok = FALSE;
 				}
 			}
@@ -86,7 +83,6 @@ common_pict_load_data (PictOptions *options, const GValue *value, PictBinData *b
 						bindata->data_length = strlen ((gchar *) bindata->data);
 						break;
 					case ENCODING_BASE64: {
-#if (GLIB_MINOR_VERSION >= 12)
 						gsize out_len;
 						bindata->data = g_base64_decode (str, &out_len);
 						if (out_len > 0)
@@ -96,35 +92,26 @@ common_pict_load_data (PictOptions *options, const GValue *value, PictBinData *b
 							bindata->data = NULL;
 							bindata->data_length = 0;
 						}
-#else
-						g_warning ("Base64 enoding/decoding is not supported in the "
-							   "GLib version %d.%d.%d",
-							   glib_major_version, glib_minor_version, glib_micro_version);
-#endif
-
 						break;
 					}
 					}
 				}
 				else {
 					*stock = GTK_STOCK_MISSING_IMAGE;
-					g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-						     "%s", _("Empty data"));
+					g_set_error (error, 0, 0, _("Empty data"));
 					allok = FALSE;
 				}
 			}
 			else {
 				*stock = GTK_STOCK_DIALOG_ERROR;
-				g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-					     "%s", _("Unhandled type of data"));
+				g_set_error (error, 0, 0, _("Unhandled type of data"));
 				allok = FALSE;
 			}
 		}
 	}
 	else {
 		*stock = GTK_STOCK_MISSING_IMAGE;
-		g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-			     "%s", _("Empty data"));
+		g_set_error (error, 0, 0, _("Empty data"));
 		allok = FALSE;
 	}
 
@@ -213,7 +200,7 @@ common_pict_make_pixbuf (PictOptions *options, PictBinData *bindata, PictAllocat
 				bindata->data_length = 0;
 
 				*stock = GTK_STOCK_DIALOG_ERROR;
-				g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
+				g_set_error (error, 0, 0,
 					     _("Error while deserializing data:\n%s"),
 					     loc_error && loc_error->message ? loc_error->message : _("No detail"));
 
@@ -223,7 +210,7 @@ common_pict_make_pixbuf (PictOptions *options, PictBinData *bindata, PictAllocat
 				retpixbuf = gdk_pixbuf_from_pixdata (&pixdata, FALSE, &loc_error);
 				if (!retpixbuf) {
 					*stock = GTK_STOCK_DIALOG_ERROR;
-					g_set_error (error, GDAUI_DATA_ENTRY_ERROR, GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
+					g_set_error (error, 0, 0,
 						     _("Error while interpreting data as an image:\n%s"),
 						     loc_error && loc_error->message ? loc_error->message : _("No detail"));
 					g_error_free (loc_error);
@@ -270,15 +257,8 @@ common_pict_make_pixbuf (PictOptions *options, PictBinData *bindata, PictAllocat
 				notice_msg = g_strdup_printf (_("Error while interpreting data as an image:\n%s"),
 							      loc_error && loc_error->message ? loc_error->message : _("No detail"));
 				*stock = GTK_STOCK_DIALOG_WARNING;
-#if GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 18
-				g_set_error (error, loc_error ? loc_error->domain : GDAUI_DATA_ENTRY_ERROR,
-					     loc_error ? loc_error->code : GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-					     "%s", notice_msg);
-#else
-				g_set_error_literal (error, loc_error ? loc_error->domain : GDAUI_DATA_ENTRY_ERROR,
-						     loc_error ? loc_error->code : GDAUI_DATA_ENTRY_INVALID_DATA_ERROR,
-						     notice_msg);
-#endif
+				g_set_error_literal (error, loc_error ? loc_error->domain : 0,
+						     loc_error ? loc_error->code : 0, notice_msg);
 				g_error_free (loc_error);
 				g_free (notice_msg);
 			}
@@ -302,19 +282,6 @@ typedef struct {
 } PictMenuData;
 static void file_load_cb (GtkWidget *button, PictMenuData *menudata);
 static void file_save_cb (GtkWidget *button, PictMenuData *menudata);
-static void copy_cb (GtkWidget *button, PictMenuData *menudata);
-
-/* Commented out because it's not used:
-static void
-menudata_free (PictMenuData *menudata)
-{
-	if (menudata->bindata) {
-		g_free (menudata->bindata->data);
-		g_free (menudata->bindata);
-	}
-	g_free (menudata);
-}
-*/
 
 void
 common_pict_create_menu (PictMenu *pictmenu, GtkWidget *attach_to, PictBinData *bindata, PictOptions *options,
@@ -324,9 +291,7 @@ common_pict_create_menu (PictMenu *pictmenu, GtkWidget *attach_to, PictBinData *
 	PictMenuData *menudata;
 	
 	menudata = g_new (PictMenuData, 1);
-	menudata->bindata = g_new (PictBinData, 1);
-	menudata->bindata->data = g_memdup (bindata->data, bindata->data_length);
-	menudata->bindata->data_length = bindata->data_length;
+	menudata->bindata = bindata;
 	menudata->options = options;
 	menudata->callback = callback;
 	menudata->data = data;
@@ -336,15 +301,7 @@ common_pict_create_menu (PictMenu *pictmenu, GtkWidget *attach_to, PictBinData *
 	g_signal_connect (menu, "deactivate", 
 			  G_CALLBACK (gtk_widget_hide), NULL);
 	pictmenu->menu = menu;
-
-	mitem = gtk_menu_item_new_with_mnemonic (_("_Copy image"));
-	gtk_widget_show (mitem);
-	gtk_container_add (GTK_CONTAINER (menu), mitem);
-	g_signal_connect (mitem, "activate",
-			  G_CALLBACK (copy_cb), menudata);
-	gtk_widget_set_sensitive (mitem, bindata->data ? TRUE : FALSE);
-	pictmenu->copy_mitem = mitem;
-
+		
 	mitem = gtk_menu_item_new_with_mnemonic (_("_Load image from file"));
 	gtk_widget_show (mitem);
 	gtk_container_add (GTK_CONTAINER (menu), mitem);
@@ -378,9 +335,7 @@ file_load_cb (GtkWidget *button, PictMenuData *menudata)
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_add_pixbuf_formats (filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dlg), filter);
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlg),
-					     gdaui_get_default_path ());	
-
+	
 	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_ACCEPT) {
 		char *filename;
 		gsize length;
@@ -388,12 +343,13 @@ file_load_cb (GtkWidget *button, PictMenuData *menudata)
 		gchar *data;
 
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dlg));
-		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg)));
 
 		if (g_file_get_contents (filename, &data, &length, &error)) {
-			g_free (menudata->bindata->data);
-			menudata->bindata->data = NULL;
-			menudata->bindata->data_length = 0;
+			if (menudata->bindata->data) {
+				g_free (menudata->bindata->data);
+				menudata->bindata->data = NULL;
+				menudata->bindata->data_length = 0;
+			}
 
 			if (menudata->options->serialize) {
 				GdkPixdata pixdata;
@@ -421,9 +377,7 @@ file_load_cb (GtkWidget *button, PictMenuData *menudata)
 
 			/* call the callback */
 			if (menudata->callback)
-				(menudata->callback) (menudata->bindata, menudata->data);
-			menudata->bindata->data = NULL;
-			menudata->bindata->data_length = 0;
+				(menudata->callback) (menudata->data);
 		}
 		else {
 			GtkWidget *msg;
@@ -462,7 +416,7 @@ add_if_writable (GdkPixbufFormat *data, PictFormat *format)
 
 		str= g_strdup_printf ("%s (%s)", gdk_pixbuf_format_get_name (data),
 				      gdk_pixbuf_format_get_description (data));
-		gtk_combo_box_append_text (format->combo, str);
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (format->combo), str);
 		g_free (str);
 		format->formats = g_slist_append (format->formats, g_strdup (gdk_pixbuf_format_get_name (data)));
 	}
@@ -483,7 +437,7 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 
 	label = gtk_label_new (_("Format image as:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	combo = gtk_combo_box_new_text ();
+	combo = gtk_combo_box_text_new ();
 	gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
 	gtk_widget_show_all (hbox);
 
@@ -493,17 +447,15 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 	g_slist_foreach (formats, (GFunc) add_if_writable, &pictformat);
 	g_slist_free (formats);
 
-	gtk_combo_box_prepend_text (GTK_COMBO_BOX (combo), _("Current format"));
+	gtk_combo_box_text_prepend_text (GTK_COMBO_BOX_TEXT (combo), _("Current format"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
 	dlg = gtk_file_chooser_dialog_new (_("Select a file to save the image to"), 
 					   GTK_WINDOW (gtk_widget_get_toplevel (button)),
 					   GTK_FILE_CHOOSER_ACTION_SAVE, 
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+					   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 					   NULL);
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlg),
-					     gdaui_get_default_path ());
 
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dlg), expander);
 	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_ACCEPT) {
@@ -514,7 +466,6 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 
 		format = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dlg));
-		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg)));
 
 		if (format == 0) {
 			/* save data AS IS */
@@ -564,38 +515,6 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 	g_slist_free (pictformat.formats);
 }
 
-static void
-copy_cb (G_GNUC_UNUSED GtkWidget *button, PictMenuData *menudata)
-{
-	GtkClipboard *cp;
-	cp = gtk_clipboard_get (gdk_atom_intern_static_string ("CLIPBOARD"));
-	if (!cp)
-		return;
-
-	GdkPixbufLoader *loader;
-	GdkPixbuf *pixbuf = NULL;
-	loader = gdk_pixbuf_loader_new ();
-	if (gdk_pixbuf_loader_write (loader, menudata->bindata->data,
-				     menudata->bindata->data_length, NULL)) {
-		if (gdk_pixbuf_loader_close (loader, NULL)) {
-			pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-			g_object_ref (pixbuf);
-		}
-		else
-			gdk_pixbuf_loader_close (loader, NULL);
-	}
-	else
-		gdk_pixbuf_loader_close (loader, NULL);
-	g_object_unref (loader);
-	
-	if (pixbuf) {
-		gtk_clipboard_set_image (cp, pixbuf);
-		g_object_unref (pixbuf);
-	}
-	else
-		gtk_clipboard_set_image (cp, NULL);
-}
-
 /* 
  * adjust the sensitiveness of the menu items in the popup menu
  */
@@ -606,7 +525,6 @@ common_pict_adjust_menu_sensitiveness (PictMenu *pictmenu, gboolean editable, Pi
 		return;
 	gtk_widget_set_sensitive (pictmenu->load_mitem, editable);
 	gtk_widget_set_sensitive (pictmenu->save_mitem, bindata->data ? TRUE : FALSE);
-	gtk_widget_set_sensitive (pictmenu->copy_mitem, bindata->data ? TRUE : FALSE);
 }
 
 /*
@@ -616,24 +534,23 @@ void
 common_pict_init_cache (PictOptions *options)
 {
 	g_assert (!options->pixbuf_hash);
-	options->pixbuf_hash = g_hash_table_new_full (g_int_hash, g_int_equal,
-						      g_free, g_object_unref);
+	options->pixbuf_hash = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_object_unref);
 }
 
 /* 
  * computes a "hash" of the binary data 
  */
-static gint
+static guint
 compute_hash (guchar *data, glong data_length)
 {
-	gint result = 0;
+	guint result = 0;
 	guchar *ptr;
 
 	if (!data)
 		return 0;
 	for (ptr = data; ptr <= data + data_length - 1; ptr++)
 		result += *ptr;
-
+	
 	return result;
 }
 
@@ -643,17 +560,18 @@ compute_hash (guchar *data, glong data_length)
 void
 common_pict_add_cached_pixbuf (PictOptions *options, const GValue *value, GdkPixbuf *pixbuf)
 {
-	gint *hash;
+	guint hash;
 	g_return_if_fail (pixbuf);
 
 	if (!options->pixbuf_hash || !value)
 		return;
+
 	else if (GDA_VALUE_HOLDS_BINARY (value)) {
 		const GdaBinary *bin;
 		bin = gda_value_get_binary (value);
-		hash = g_new (guint, 1);
-		*hash = compute_hash (bin->data, bin->binary_length);
-		g_hash_table_insert (options->pixbuf_hash, hash, g_object_ref (pixbuf));
+		hash = compute_hash (bin->data, bin->binary_length);
+		g_hash_table_insert (options->pixbuf_hash, GUINT_TO_POINTER (hash), pixbuf);
+		g_object_ref (pixbuf);
 	}
 	else if (GDA_VALUE_HOLDS_BLOB (value)) {
 		const GdaBinary *bin;
@@ -663,9 +581,9 @@ common_pict_add_cached_pixbuf (PictOptions *options, const GValue *value, GdkPix
 		if (bin) {
 			if (!bin->data && blob->op)
 				gda_blob_op_read_all (blob->op, (GdaBlob*) blob);
-			hash = g_new (guint, 1);
-			*hash = compute_hash (bin->data, bin->binary_length);
-			g_hash_table_insert (options->pixbuf_hash, hash, g_object_ref (pixbuf));
+			hash = compute_hash (bin->data, bin->binary_length);
+			g_hash_table_insert (options->pixbuf_hash, GUINT_TO_POINTER (hash), pixbuf);
+			g_object_ref (pixbuf);
 		}
 	}
 }
@@ -677,7 +595,7 @@ GdkPixbuf *
 common_pict_fetch_cached_pixbuf (PictOptions *options, const GValue *value)
 {
 	GdkPixbuf *pixbuf = NULL;
-	gint hash;
+	guint hash;
 
 	if (!options->pixbuf_hash)
 		return NULL;
@@ -688,7 +606,7 @@ common_pict_fetch_cached_pixbuf (PictOptions *options, const GValue *value)
 		bin = gda_value_get_binary (value);
 		if (bin) {
 			hash = compute_hash (bin->data, bin->binary_length);
-			pixbuf = g_hash_table_lookup (options->pixbuf_hash, &hash);
+			pixbuf = g_hash_table_lookup (options->pixbuf_hash, GUINT_TO_POINTER (hash));
 		}
 	}
 	else if (GDA_VALUE_HOLDS_BLOB (value)) {
@@ -700,7 +618,7 @@ common_pict_fetch_cached_pixbuf (PictOptions *options, const GValue *value)
 			if (!bin->data && blob->op)
 				gda_blob_op_read_all (blob->op, (GdaBlob*) blob);
 			hash = compute_hash (bin->data, bin->binary_length);
-			pixbuf = g_hash_table_lookup (options->pixbuf_hash, &hash);
+			pixbuf = g_hash_table_lookup (options->pixbuf_hash, GUINT_TO_POINTER (hash));
 		}
 	}
 
@@ -765,12 +683,7 @@ common_pict_get_value (PictBinData *bindata, PictOptions *options, GType gtype)
 						 bindata->data_length);
 				break;
 			case ENCODING_BASE64: 
-#if (GLIB_MINOR_VERSION >= 12)
 				str = g_base64_encode (bindata->data, bindata->data_length);
-#else
-				g_warning ("Base64 enoding/decoding is not supported in the GLib version %d.%d.%d",
-					   glib_major_version, glib_minor_version, glib_micro_version);
-#endif
 				break;
 			}
 			
