@@ -1,21 +1,21 @@
-/*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* gdaui-data-cell-renderer-pict.c
+ *
+ * Copyright (C) 2006 - 2010 Vivien Malerba <malerba@gdaui.org>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <stdlib.h>
@@ -41,15 +41,14 @@ static void gdaui_data_cell_renderer_pict_dispose       (GObject *object);
 static void gdaui_data_cell_renderer_pict_init       (GdauiDataCellRendererPict      *celltext);
 static void gdaui_data_cell_renderer_pict_class_init (GdauiDataCellRendererPictClass *class);
 static void gdaui_data_cell_renderer_pict_render     (GtkCellRenderer            *cell,
-						      GdkWindow                  *window,
+						      cairo_t                    *cr,
 						      GtkWidget                  *widget,
-						      GdkRectangle               *background_area,
-						      GdkRectangle               *cell_area,
-						      GdkRectangle               *expose_area,
+						      const GdkRectangle         *background_area,
+						      const GdkRectangle         *cell_area,
 						      GtkCellRendererState        flags);
 static void gdaui_data_cell_renderer_pict_get_size   (GtkCellRenderer            *cell,
 						      GtkWidget                  *widget,
-						      GdkRectangle               *cell_area,
+						      const GdkRectangle        *cell_area,
 						      gint                       *x_offset,
 						      gint                       *y_offset,
 						      gint                       *width,
@@ -58,8 +57,8 @@ static gboolean gdaui_data_cell_renderer_pict_activate  (GtkCellRenderer
 							 GdkEvent                   *event,
 							 GtkWidget                  *widget,
 							 const gchar                *path,
-							 GdkRectangle               *background_area,
-							 GdkRectangle               *cell_area,
+							 const GdkRectangle         *background_area,
+							 const GdkRectangle         *cell_area,
 							 GtkCellRendererState        flags);
 
 /* get a pointer to the parents to be able to call their destructor */
@@ -355,7 +354,7 @@ gdaui_data_cell_renderer_pict_set_property (GObject *object,
  * in the model, thus causing the check button to reflect the state of
  * the model.
  *
- * Returns: the new cell renderer
+ * Return value: the new cell renderer
  */
 GtkCellRenderer *
 gdaui_data_cell_renderer_pict_new (GdaDataHandler *dh, GType type, const gchar *options)
@@ -379,7 +378,7 @@ gdaui_data_cell_renderer_pict_new (GdaDataHandler *dh, GType type, const gchar *
 static void
 gdaui_data_cell_renderer_pict_get_size (GtkCellRenderer *cell,
 					GtkWidget       *widget,
-					GdkRectangle    *cell_area,
+					const GdkRectangle *cell_area,
 					gint            *x_offset,
 					gint            *y_offset,
 					gint            *width,
@@ -394,17 +393,16 @@ gdaui_data_cell_renderer_pict_get_size (GtkCellRenderer *cell,
 
 static void
 gdaui_data_cell_renderer_pict_render (GtkCellRenderer      *cell,
-				      GdkWindow            *window,
+				      cairo_t              *cr,
 				      GtkWidget            *widget,
-				      GdkRectangle         *background_area,
-				      GdkRectangle         *cell_area,
-				      GdkRectangle         *expose_area,
+				      const GdkRectangle   *background_area,
+				      const GdkRectangle   *cell_area,
 				      GtkCellRendererState  flags)
 {
 	GdauiDataCellRendererPict *datacell = GDAUI_DATA_CELL_RENDERER_PICT (cell);
 	GtkCellRendererClass *pixbuf_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_PIXBUF);
 
-	(pixbuf_class->render) (cell, window, widget, background_area, cell_area, expose_area, flags);
+	(pixbuf_class->render) (cell, cr, widget, background_area, cell_area, flags);
 
 	if (datacell->priv->to_be_deleted) {
 		GtkStyle *style;
@@ -414,8 +412,7 @@ gdaui_data_cell_renderer_pict_render (GtkCellRenderer      *cell,
 		g_object_get ((GObject*) cell, "xpad", &xpad, NULL);
 
 		gtk_paint_hline (style,
-				 window, GTK_STATE_SELECTED,
-				 cell_area,
+				 cr, GTK_STATE_SELECTED,
 				 widget,
 				 "hline",
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
@@ -423,17 +420,16 @@ gdaui_data_cell_renderer_pict_render (GtkCellRenderer      *cell,
 		g_object_unref (style);
 	}
 	if (datacell->priv->invalid)
-		gdaui_data_cell_renderer_draw_invalid_area (window, cell_area);
+		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
 }
 
 static void
-pict_data_changed_cb (PictBinData *bindata, GdauiDataCellRendererPict *pictcell)
+pict_data_changed_cb (GdauiDataCellRendererPict *pictcell)
 {
 	GValue *value;
 
-	value = common_pict_get_value (bindata, &(pictcell->priv->options),
+	value = common_pict_get_value (&(pictcell->priv->bindata), &(pictcell->priv->options),
 				       pictcell->priv->type);
-	g_free (bindata->data);
 	g_signal_emit (G_OBJECT (pictcell), pixbuf_cell_signals[CHANGED], 0,
 		       g_object_get_data (G_OBJECT (pictcell), "last-path"), value);
 	gda_value_free (value);
@@ -444,8 +440,8 @@ gdaui_data_cell_renderer_pict_activate  (GtkCellRenderer            *cell,
 					 G_GNUC_UNUSED GdkEvent                   *event,
 					 GtkWidget                  *widget,
 					 const gchar                *path,
-					 G_GNUC_UNUSED GdkRectangle               *background_area,
-					 G_GNUC_UNUSED GdkRectangle               *cell_area,
+					 G_GNUC_UNUSED const GdkRectangle *background_area,
+					 G_GNUC_UNUSED const GdkRectangle *cell_area,
 					 G_GNUC_UNUSED GtkCellRendererState        flags)
 {
 	GdauiDataCellRendererPict *pictcell;
@@ -455,13 +451,10 @@ gdaui_data_cell_renderer_pict_activate  (GtkCellRenderer            *cell,
 		int event_time;
 
 		g_object_set_data_full (G_OBJECT (pictcell), "last-path", g_strdup (path), g_free);
-		if (pictcell->priv->popup_menu.menu) {
-			gtk_widget_destroy (pictcell->priv->popup_menu.menu);
-			pictcell->priv->popup_menu.menu = NULL;
-		}
-		common_pict_create_menu (&(pictcell->priv->popup_menu), widget, &(pictcell->priv->bindata),
-					 &(pictcell->priv->options),
-					 (PictCallback) pict_data_changed_cb, pictcell);
+		if (!pictcell->priv->popup_menu.menu)
+			common_pict_create_menu (&(pictcell->priv->popup_menu), widget, &(pictcell->priv->bindata),
+						 &(pictcell->priv->options),
+						 (PictCallback) pict_data_changed_cb, pictcell);
 
 		common_pict_adjust_menu_sensitiveness (&(pictcell->priv->popup_menu), pictcell->priv->editable,
 						       &(pictcell->priv->bindata));
