@@ -1,21 +1,21 @@
-/*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* gdaui-entry-pict.c
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Copyright (C) 2006 - 2011 Vivien Malerba
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
 #include <glib/gi18n-lib.h>
@@ -289,13 +289,10 @@ do_popup_menu (GtkWidget *widget, GdkEventButton *event, GdauiEntryPict *mgpict)
 {
 	int button, event_time;
 	
-	if (mgpict->priv->popup_menu.menu) {
-		gtk_widget_destroy (mgpict->priv->popup_menu.menu);
-		mgpict->priv->popup_menu.menu = NULL;
-	}
-	common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
-				 &(mgpict->priv->options), 
-				 (PictCallback) pict_data_changed_cb, mgpict);
+	if (!mgpict->priv->popup_menu.menu)
+		common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
+					 &(mgpict->priv->options), 
+					 (PictCallback) pict_data_changed_cb, mgpict);
 
 	common_pict_adjust_menu_sensitiveness (&(mgpict->priv->popup_menu), mgpict->priv->editable, 
 						       &(mgpict->priv->bindata));
@@ -328,14 +325,11 @@ event_cb (GtkWidget *widget, GdkEvent *event, GdauiEntryPict *mgpict)
 	}
 	if ((event->type == GDK_2BUTTON_PRESS) && (((GdkEventButton *) event)->button == 1)) {
 		if (mgpict->priv->editable) {
-			if (mgpict->priv->popup_menu.menu) {
-				gtk_widget_destroy (mgpict->priv->popup_menu.menu);
-				mgpict->priv->popup_menu.menu = NULL;
-			}
-			common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
-						 &(mgpict->priv->options), 
-						 (PictCallback) pict_data_changed_cb, mgpict);
-			
+			if (!mgpict->priv->popup_menu.menu) 
+				common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
+							 &(mgpict->priv->options), 
+							 (PictCallback) pict_data_changed_cb, mgpict);
+
 			common_pict_adjust_menu_sensitiveness (&(mgpict->priv->popup_menu), mgpict->priv->editable, 
 							       &(mgpict->priv->bindata));
 			
@@ -385,16 +379,10 @@ display_image (GdauiEntryPict *mgpict, const GValue *value, const gchar *error_s
 	PictAllocation alloc;
 	GError *error = NULL;
 
-#if GTK_CHECK_VERSION(2,18,0)
 	GtkAllocation walloc;
 	gtk_widget_get_allocation (mgpict->priv->sw, &walloc);
 	alloc.width = walloc.width;
 	alloc.height = walloc.height;
-#else
-	alloc.width = mgpict->priv->sw->allocation.width;
-	alloc.height = mgpict->priv->sw->allocation.height;
-#endif
-
 	alloc.width = MAX (alloc.width, 10);
 	alloc.height = MAX (alloc.height, 10);
 
@@ -521,12 +509,8 @@ value_is_equal_to (GdauiEntryWrapper *mgwrap, const GValue *value)
 						    mgpict->priv->bindata.data_length);
 				break;
 			case ENCODING_BASE64: 
-#if (GLIB_MINOR_VERSION >= 12)
-				curstr = g_base64_encode (mgpict->priv->bindata.data, mgpict->priv->bindata.data_length);
-#else
-				g_warning ("Base64 enoding/decoding is not supported in the GLib version %d.%d.%d",
-					   glib_major_version, glib_minor_version, glib_micro_version);
-#endif
+				curstr = g_base64_encode (mgpict->priv->bindata.data,
+							  mgpict->priv->bindata.data_length);
 				break;
 			default:
 				g_assert_not_reached ();
