@@ -85,7 +85,8 @@ gdaui_data_store_get_type (void)
 			NULL,
 			sizeof (GdauiDataStore),
 			0,
-			(GInstanceInitFunc) gdaui_data_store_init
+			(GInstanceInitFunc) gdaui_data_store_init,
+			0
 		};
 
 		static const GInterfaceInfo data_model_info = {
@@ -154,7 +155,7 @@ gdaui_data_store_init (GdauiDataStore *store)
 }
 
 static void
-row_inserted_cb (GdaDataProxy *proxy, gint row, GtkTreeModel *store)
+row_inserted_cb (G_GNUC_UNUSED GdaDataProxy *proxy, gint row, GtkTreeModel *store)
 {
 	GtkTreePath *path;
 	GtkTreeIter iter;
@@ -169,7 +170,7 @@ row_inserted_cb (GdaDataProxy *proxy, gint row, GtkTreeModel *store)
 }
 
 static void
-row_updated_cb (GdaDataProxy *proxy, gint row, GtkTreeModel *store)
+row_updated_cb (G_GNUC_UNUSED GdaDataProxy *proxy, gint row, GtkTreeModel *store)
 {
 	GtkTreePath *path;
 	GtkTreeIter iter;
@@ -183,7 +184,7 @@ row_updated_cb (GdaDataProxy *proxy, gint row, GtkTreeModel *store)
 }
 
 static void
-row_removed_cb (GdaDataProxy *proxy, gint row, GtkTreeModel *store)
+row_removed_cb (G_GNUC_UNUSED GdaDataProxy *proxy, gint row, GtkTreeModel *store)
 {
 	GtkTreePath *path;
 
@@ -289,6 +290,9 @@ gdaui_data_store_set_property (GObject *object,
 				      g_value_get_boolean (value), NULL);
 			store->priv->stamp = g_random_int ();
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
@@ -319,6 +323,9 @@ gdaui_data_store_get_property (GObject *object,
 			g_value_set_boolean (value, prop);
 			break;
 		}
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
@@ -817,7 +824,7 @@ data_store_iter_children (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIt
 }
 
 static gboolean
-data_store_iter_has_child (GtkTreeModel *tree_model, GtkTreeIter *iter)
+data_store_iter_has_child (G_GNUC_UNUSED GtkTreeModel *tree_model, G_GNUC_UNUSED GtkTreeIter *iter)
 {
         return FALSE;
 }
@@ -859,7 +866,7 @@ data_store_iter_nth_child (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeI
 }
 
 static gboolean
-data_store_iter_parent (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child)
+data_store_iter_parent (G_GNUC_UNUSED GtkTreeModel *tree_model, G_GNUC_UNUSED GtkTreeIter *iter, G_GNUC_UNUSED GtkTreeIter *child)
 {
         return FALSE;
 }
