@@ -1,6 +1,5 @@
-/* gdaui-grid.h
- *
- * Copyright (C) 2002 - 2009 Vivien Malerba <malerba@gnome-db.org>
+/*
+ * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -29,7 +28,7 @@ G_BEGIN_DECLS
 #define GDAUI_GRID(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gdaui_grid_get_type(), GdauiGrid)
 #define GDAUI_GRID_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gdaui_grid_get_type (), GdauiGridClass)
 #define GDAUI_IS_GRID(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gdaui_grid_get_type ())
-
+#define GDAUI_IS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), GDAUI_TYPE_GRID))
 
 typedef struct _GdauiGrid      GdauiGrid;
 typedef struct _GdauiGridClass GdauiGridClass;
@@ -49,9 +48,15 @@ struct _GdauiGridClass
 	GtkVBoxClass       parent_class;
 };
 
-/* 
- * Generic widget's methods 
+/**
+ * SECTION:gdaui-grid
+ * @short_description: Grid widget to manipulate data in a #GdaDataModel, with decorations
+ * @title: GdauiGrid
+ * @stability: Stable
+ * @Image:
+ * @see_also: The #GdauiRawGrid widget which is used by the #GdaGrid widget.
  */
+
 GType             gdaui_grid_get_type            (void) G_GNUC_CONST;
 
 GtkWidget        *gdaui_grid_new                 (GdaDataModel *model);
