@@ -1,21 +1,21 @@
-/*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* gdaui-server-operation.c
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Copyright (C) 2006 - 2010 Vivien Malerba
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
 #include <stdlib.h>
@@ -451,6 +451,7 @@ fill_create_widget (GdauiServerOperation *form, const gchar *path, gchar **secti
 	}
 	case GDA_SERVER_OPERATION_NODE_DATA_MODEL: {
 		GdaDataModel *model;
+		GdaDataProxy *proxy;
 		GtkWidget *winfo;
 		GtkWidget *box, *grid;
 
@@ -469,6 +470,7 @@ fill_create_widget (GdauiServerOperation *form, const gchar *path, gchar **secti
 						 GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE);
 		gtk_widget_show (grid);
 
+		proxy = gdaui_data_proxy_get_proxy (GDAUI_DATA_PROXY (grid));
 		g_object_set (G_OBJECT (grid), "info-cell-visible", FALSE, NULL);
 
 		winfo = gdaui_data_proxy_info_new (GDAUI_DATA_PROXY (grid),
@@ -938,7 +940,7 @@ sequence_item_added_cb (GdaServerOperation *op, const gchar *seq_path, gint item
 			}
 
 			/* move children DOWN if necessary and change the "_index" property */
-			if (top_attach >= (guint)item_index) {
+			if (top_attach >= item_index) {
 				struct MoveChild *mc;
 				gint index;
 
@@ -1014,7 +1016,7 @@ sequence_item_remove_cb (GdaServerOperation *op, const gchar *seq_path, gint ite
 			guint top_attach;
 			gtk_container_child_get (GTK_CONTAINER (table), child,
 						 "top-attach", &top_attach, NULL);
-			if (top_attach == (guint)item_index) {
+			if (top_attach == item_index) {
 				gtk_widget_destroy (child);
 				g_list_free (children);
 				children = gtk_container_get_children (GTK_CONTAINER (table));
@@ -1044,7 +1046,7 @@ sequence_item_remove_cb (GdaServerOperation *op, const gchar *seq_path, gint ite
 			}
 
 			/* move widgets UP if necessary and change the "_index" property */
-			if (top_attach > (guint)item_index) {
+			if (top_attach > item_index) {
 				struct MoveChild *mc;
 				gint index;
 
@@ -1081,9 +1083,9 @@ sequence_item_remove_cb (GdaServerOperation *op, const gchar *seq_path, gint ite
 /**
  * gdaui_server_operation_new_in_dialog
  * @op: a #GdaServerOperation object
- * @parent: (allow-none): the parent window for the new dialog, or %NULL
- * @title: (allow-none): the title of the dialog window, or %NULL
- * @header: (allow-none): a helper text displayed at the top of the dialog, or %NULL
+ * @parent: the parent window for the new dialog, or %NULL
+ * @title: the title of the dialog window, or %NULL
+ * @header: a helper text displayed at the top of the dialog, or %NULL
  *
  * Creates a new #GdauiServerOperation widget in the same way as gdaui_server_operation_new()
  * and puts it into a #GtkDialog widget. The returned dialog has the "Ok" and "Cancel" buttons
@@ -1118,11 +1120,7 @@ gdaui_server_operation_new_in_dialog (GdaServerOperation *op, GtkWindow *parent,
 					   GTK_STOCK_CANCEL,
 					   GTK_RESPONSE_REJECT,
 					   NULL);
-#if GTK_CHECK_VERSION(2,18,0)
 	dcontents = gtk_dialog_get_content_area (GTK_DIALOG (dlg));
-#else
-	dcontents = GTK_DIALOG (dlg)->vbox;
-#endif
 
 	if (header && *header) {
 		GtkWidget *label;
