@@ -87,7 +87,8 @@ gda_batch_get_type (void)
 			NULL,
 			sizeof (GdaBatch),
 			0,
-			(GInstanceInitFunc) gda_batch_init
+			(GInstanceInitFunc) gda_batch_init,
+			0
 		};
 		
 		g_static_mutex_lock (&registering);
@@ -132,7 +133,7 @@ gda_batch_class_init (GdaBatchClass * klass)
 }
 
 static void
-m_changed_cb (GdaBatch *batch, GdaStatement *changed_stmt)
+m_changed_cb (G_GNUC_UNUSED GdaBatch *batch, G_GNUC_UNUSED GdaStatement *changed_stmt)
 {
 	
 }
@@ -168,7 +169,7 @@ gda_batch_new (void)
  * 
  * Copy constructor
  *
- * Returns: a the new copy of @orig
+ * Returns: (transfer full): a the new copy of @orig
  */
 GdaBatch *
 gda_batch_copy (GdaBatch *orig)
@@ -236,7 +237,7 @@ gda_batch_finalize (GObject *object)
 static void 
 gda_batch_set_property (GObject *object,
 			     guint param_id,
-			     const GValue *value,
+			     G_GNUC_UNUSED const GValue *value,
 			     GParamSpec *pspec)
 {
 	GdaBatch *batch;
@@ -254,7 +255,7 @@ gda_batch_set_property (GObject *object,
 static void
 gda_batch_get_property (GObject *object,
 			     guint param_id,
-			     GValue *value,
+			     G_GNUC_UNUSED GValue *value,
 			     GParamSpec *pspec)
 {
 	GdaBatch *batch;
@@ -386,7 +387,7 @@ gda_batch_get_statements (GdaBatch *batch)
 /**
  * gda_batch_get_parameters:
  * @batch: a #GdaBatch object
- * @out_params: (out) (tranfer full) (allow-none): a place to store a new #GdaSet object, or %NULL
+ * @out_params: (out) (transfer full) (allow-none): a place to store a new #GdaSet object, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Get a new #GdaSet object which groups all the execution parameters
