@@ -1,5 +1,5 @@
-/* GDA server library
- * Copyright (C) 1998 - 2007 The GNOME Foundation.
+/*
+ * Copyright (C) 1998 - 2011 The GNOME Foundation.
  *
  * AUTHORS:
  *      Michael Lausch <michael@lausch.at>
@@ -43,6 +43,13 @@ struct _GdaConnectionEvent {
 
 struct _GdaConnectionEventClass {
 	GObjectClass parent_class;
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_gda_reserved1) (void);
+	void (*_gda_reserved2) (void);
+	void (*_gda_reserved3) (void);
+	void (*_gda_reserved4) (void);
 };
 
 typedef enum {
@@ -79,11 +86,19 @@ typedef enum
 #define GDA_SQLSTATE_NO_ERROR "00000"
 #define GDA_SQLSTATE_GENERAL_ERROR "HY000"
 
+/**
+ * SECTION:gda-connection-event
+ * @short_description: Any event which has occurred on a #GdaConnection
+ * @title: GdaConnectionEvent
+ * @stability: Stable
+ * @see_also: #GdaConnection
+ *
+ * Events occurring on a connection are each represented as a #GdaConnectionEvent object. Each #GdaConnection
+ * is responsible for keeping a list of past events; that list can be consulted using the 
+ * gda_connection_get_events() function.
+ */
+
 GType                   gda_connection_event_get_type (void) G_GNUC_CONST;
-GdaConnectionEvent     *gda_connection_event_new (GdaConnectionEventType type);
-void                    gda_connection_event_free (GdaConnectionEvent * event);
-GList                  *gda_connection_event_list_copy (const GList * events);
-void                    gda_connection_event_list_free (GList * events);
 
 void                    gda_connection_event_set_event_type (GdaConnectionEvent *event, GdaConnectionEventType type);
 GdaConnectionEventType  gda_connection_event_get_event_type (GdaConnectionEvent *event);
