@@ -1,6 +1,5 @@
 /* 
- * GDA common library
- * Copyright (C) 1998 - 2010 The GNOME Foundation.
+ * Copyright (C) 1998 - 2011 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -772,7 +771,9 @@ gda_data_model_set_values (GdaDataModel *model, gint row, GList *values, GError
  * @model: a #GdaDataModel object.
  *
  * Creates a new iterator object #GdaDataModelIter object which can be used to iterate through
- * rows in @model.
+ * rows in @model. The new #GdaDataModelIter does not hold any reference to @model (ie. if @model
+ * is destroyed at some point, the new iterator will become useless but in any case it will not prevent
+ * the data model from being destroyed).
  *
  * Depending on the data model's implementation, a new #GdaDataModelIter object may be created,
  * or a reference to an already existing #GdaDataModelIter may be returned.
@@ -995,6 +996,31 @@ gda_data_model_send_hint (GdaDataModel *model, GdaDataModelHint hint, const GVal
 		(GDA_DATA_MODEL_GET_CLASS (model)->i_send_hint) (model, hint, hint_value);
 }
 
+/**
+ * gda_data_model_get_exceptions:
+ * @model: a #GdaDataModel
+ *
+ * Get the global data model exception(s) that occurred when using @model.
+ * This is useful for example for the LDAP related
+ * data models where some rows may be missing because the LDAP search has reached a limit
+ * imposed by the LDAP server.
+ *
+ * Returns: (transfer none) (element-type GError) (array zero-terminated=1): a pointer to a %NULL terminated array of #GError, or %NULL.
+ *
+ * Since: 4.2.6
+ */
+GError **
+gda_data_model_get_exceptions (GdaDataModel *model)
+{
+	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
+
+	if (GDA_DATA_MODEL_GET_CLASS (model)->i_get_exceptions)
+		return (GDA_DATA_MODEL_GET_CLASS (model)->i_get_exceptions) (model);
+	else
+		return NULL;
+}
+
+
 static gchar *export_to_text_separated (GdaDataModel *model, const gint *cols, gint nb_cols, 
 					const gint *rows, gint nb_rows, gchar sep, gchar quote, gboolean field_quotes,
 					gboolean null_as_empty, gboolean invalid_as_null);
@@ -1700,7 +1726,16 @@ gda_data_model_add_data_from_xml_node (GdaDataModel *model, xmlNodePtr node, GEr
  *
  * The @cols_trans is a hash table for which keys are @to columns numbers and the values are
  * the corresponding column numbers in the @from data model. To set the values of a column in @to to NULL,
- * create an entry in the hash table with a negative value.
+ * create an entry in the hash table with a negative value. For example:
+ * <programlisting><![CDATA[GHashTable *hash;
+ * gint *ptr;
+ * hash = g_hash_table_new_full (g_int_hash, g_int_equal, g_free, NULL);
+ * ptr = g_new (gint, 1);
+ * *ptr = 2;
+ * g_hash_table_insert (hash, ptr, GINT_TO_POINTER (3));
+ * gda_data_model_import_from_model (...);
+ * g_hash_table_free (hash);
+ * ]]></programlisting>
  *
  * Upon errors FALSE will be returned and @error will be assigned a
  * #GError from the #GDA_DATA_MODEL_ERROR domain.
@@ -1749,8 +1784,8 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 		GdaColumn *column;
 
 		if (cols_trans) {
-			col = GPOINTER_TO_INT (g_hash_table_lookup (cols_trans, GINT_TO_POINTER (i)));
-			if (col >= from_nb_cols) {
+			col = GPOINTER_TO_INT (g_hash_table_lookup (cols_trans, &i));
+			if ((col < 0) || (col >= from_nb_cols)) {
 				g_slist_free (copy_params);
 				g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_COLUMN_OUT_OF_RANGE_ERROR,
 					     _("Inexistent column in source data model: %d"), col);
@@ -2474,7 +2509,29 @@ real_gda_data_model_dump_as_string (GdaDataModel *model, gboolean dump_attribute
 			g_strfreev (cols_str [i]);
 		g_free (cols_str);
 	}
-	g_string_append_printf (string, ngettext("(%d row)\n", "(%d rows)\n", n_rows), n_rows);
+
+	/* status message */
+	g_string_append_c (string, '(');
+	if (n_rows > 0)
+		g_string_append_printf (string, ngettext("%d row", "%d rows", n_rows), n_rows);
+	else
+		g_string_append_printf (string, _("0 row"));
+
+	GError **exceptions;
+	exceptions = gda_data_model_get_exceptions (model);
+	if (exceptions) {
+		gint i;
+		for (i = 0; exceptions[i]; i++) {
+			GError *ex;
+			ex = exceptions[i];
+			if (ex && ex->message) {
+				g_string_append (string, ", ");
+				g_string_append (string, ex->message);
+			}
+		}
+	}
+	g_string_append (string, ")\n");
+
 
  out:
 	if (ramodel)
