@@ -1,4 +1,4 @@
-/* GDA Library
+/*
  * Copyright (C) 1998 - 2008 The GNOME Foundation.
  *
  * This Library is free software; you can redistribute it and/or
@@ -166,7 +166,7 @@ gda_init (void)
 	g_assert (type);
 	type = GDA_TYPE_TIMESTAMP;
 	g_assert (type);
-	type = GDA_TYPE_ERROR;
+	type = G_TYPE_ERROR;
 	g_assert (type);
 
 	/* acquire locale */
