@@ -267,7 +267,7 @@ gda_set_class_init (GdaSetClass *class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GdaSetClass, validate_holder_change),
 			      validate_accumulator, NULL,
-			      _gda_marshal_ERROR__OBJECT_VALUE, GDA_TYPE_ERROR, 2,
+			      _gda_marshal_ERROR__OBJECT_VALUE, G_TYPE_ERROR, 2,
 			      GDA_TYPE_HOLDER, G_TYPE_VALUE);
 	/**
 	 * GdaSet::validate-set
@@ -285,7 +285,7 @@ gda_set_class_init (GdaSetClass *class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GdaSetClass, validate_set),
 			      validate_accumulator, NULL,
-			      _gda_marshal_ERROR__VOID, GDA_TYPE_ERROR, 0);
+			      _gda_marshal_ERROR__VOID, G_TYPE_ERROR, 0);
 	/**
 	 * GdaSet::holder-attr-changed
 	 * @set: the #GdaSet
@@ -473,7 +473,7 @@ gda_set_copy (GdaSet *set)
 }
 
 /**
- * gda_set_new_inline:
+ * gda_set_new_inline: (skip)
  * @nb: the number of value holders which will be contained in the new #GdaSet
  * @...: a serie of a (const gchar*) id, (GType) type, and value
  *
@@ -584,7 +584,7 @@ gda_set_new_inline (gint nb, ...)
 }
 
 /**
- * gda_set_set_holder_value:
+ * gda_set_set_holder_value: (skip)
  * @set: a #GdaSet object
  * @error: (allow-none): a place to store errors, or %NULL
  * @holder_id: the ID of the holder to set the value
