@@ -1,9 +1,10 @@
-/* GDA common library
- * Copyright (C) 1998 - 2009 The GNOME Foundation.
+/*
+ * Copyright (C) 1998 - 2011 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
  *      Vivien Malerba <malerba@gnome-db.org>
+ *      Daniel Espinosa <esodan@gmail.com>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -33,6 +34,16 @@
 
 G_BEGIN_DECLS
 
+/**
+ * SECTION:gda-util
+ * @short_description: Utility functions
+ * @title: Utility functions
+ * @stability: Stable
+ * @see_also:
+ *
+ * Some useful functions.
+ */
+
 /*
  * Type utilities
  */
@@ -55,12 +66,16 @@ gchar       *gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaS
  * Param & model utilities
  */
 gboolean     gda_utility_check_data_model (GdaDataModel *model, gint nbcols, ...);
+gboolean     gda_utility_check_data_model_v (GdaDataModel *model, gint nbcols, GType* types);
 gboolean     gda_utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent, 
 					      const gint *cols, gint nb_cols, const gint *rows, gint nb_rows,
 					      gboolean use_col_ids);
 const gchar *gda_utility_data_model_find_column_description (GdaDataSelect *model, const gchar *field_name);
 gboolean     gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *sources, GError **error);
 
+GdaSqlStatement *gda_statement_rewrite_for_default_values (GdaStatement *stmt, GdaSet *params,
+							   gboolean remove, GError **error);
+
 /* 
  * translate any text to an alphanumerical text 
  */
