@@ -1,6 +1,5 @@
-/* gda-handler-string.h
- *
- * Copyright (C) 2003 - 2008 Vivien Malerba
+/*
+ * Copyright (C) 2003 - 2011 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -39,7 +38,6 @@ typedef struct _GdaHandlerStringPriv  GdaHandlerStringPriv;
 struct _GdaHandlerString
 {
 	GObject                object;
-
 	GdaHandlerStringPriv  *priv;
 };
 
@@ -47,8 +45,23 @@ struct _GdaHandlerString
 struct _GdaHandlerStringClass
 {
 	GObjectClass           parent_class;
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_gda_reserved1) (void);
+	void (*_gda_reserved2) (void);
 };
 
+/**
+ * SECTION:gda-handler-string
+ * @short_description: Default handler for string values
+ * @title: GdaHanderString
+ * @stability: Stable
+ * @see_also: #GdaDataHandler interface
+ *
+ * You should normally not need to use this API, refer to the #GdaDataHandler
+ * interface documentation for more information.
+ */
 
 GType           gda_handler_string_get_type          (void) G_GNUC_CONST;
 GdaDataHandler *gda_handler_string_new               (void);
