@@ -1,6 +1,5 @@
-/* gda-handler-time.h
- *
- * Copyright (C) 2003 - 2008 Vivien Malerba
+/*
+ * Copyright (C) 2003 - 2011 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -39,7 +38,6 @@ typedef struct _GdaHandlerTimePriv  GdaHandlerTimePriv;
 struct _GdaHandlerTime
 {
 	GObject              object;
-
 	GdaHandlerTimePriv  *priv;
 };
 
@@ -47,8 +45,23 @@ struct _GdaHandlerTime
 struct _GdaHandlerTimeClass
 {
 	GObjectClass         parent_class;
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_gda_reserved1) (void);
+	void (*_gda_reserved2) (void);
 };
 
+/**
+ * SECTION:gda-handler-time
+ * @short_description: Default handler for time values
+ * @title: GdaHanderTime
+ * @stability: Stable
+ * @see_also: #GdaDataHandler interface
+ *
+ * You should normally not need to use this API, refer to the #GdaDataHandler
+ * interface documentation for more information.
+ */
 
 GType           gda_handler_time_get_type      (void) G_GNUC_CONST;
 GdaDataHandler *gda_handler_time_new           (void);
