@@ -1,5 +1,8 @@
-/* 
- * Copyright (C) 2007 - 2008 Vivien Malerba
+/*
+ * Copyright (C) 2007 - 2011 The GNOME Foundation.
+ *
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -23,18 +26,20 @@
 #include <glib.h>
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
 /* utility functions */
-gchar *_remove_quotes (gchar *str);
-gchar *_add_quotes (const gchar *str);
-
+gchar    *_remove_quotes (gchar *str);
 gchar    *_json_quote_string (const gchar *str);
-
 gboolean  _string_is_identifier (const gchar *str);
-gboolean  _identifier_needs_quotes (const gchar *str);
 gboolean  _split_identifier_string (gchar *str, gchar **remain, gchar **last);
-gchar    *_identifier_unquote (gchar *str);
+
+gchar    *gda_sql_identifier_force_quotes (const gchar *str);
+gchar    *gda_sql_identifier_prepare_for_compare (gchar *str);
 
 /* to be removed, only here for debug */
-gchar *gda_sql_value_stringify (const GValue *value);
+gchar    *gda_sql_value_stringify (const GValue *value);
+
+G_END_DECLS
 
 #endif
