@@ -1,21 +1,24 @@
 /*
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2008 - 2011 The GNOME Foundation
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *         Vivien Malerba <malerba@gnome-db.org>
+ *         Bas Driessen <bas.driessen@xobas.com>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -55,8 +58,6 @@ static gchar *internal_sql[] = {
 	"PRAGMA database_list",
 
 	/* I_PRAGMA_TABLE_INFO */
-	/* warning: this can return an error as "no such function XXX" if a view has been
-	 * defined using a function not native of SQLite (and thus not available in Libgda) */
 	"PRAGMA table_info (##tblname::string)",
 
 	/* I_PRAGMA_INDEX_LIST */
@@ -961,22 +962,15 @@ fill_columns_model (GdaConnection *cnc, SqliteConnectionData *cdata,
 	GType col_types[] = {G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, 
 			     G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_NONE};
 	GdaStatement *stmt;
-	GError *lerror = NULL;
 	
 	schema_name = g_value_get_string (p_table_schema);
-	stmt = get_statement (I_PRAGMA_TABLE_INFO, schema_name, g_value_get_string (p_table_name), NULL);
+	stmt = get_statement (I_PRAGMA_TABLE_INFO, schema_name, g_value_get_string (p_table_name), error);
 	tmpmodel = gda_connection_statement_execute_select_full (cnc, stmt, pragma_set, 
 								 GDA_STATEMENT_MODEL_RANDOM_ACCESS, 
-								 col_types, &lerror);
+								 col_types, error);
 	g_object_unref (stmt);
-	if (!tmpmodel) {
-		if (lerror && lerror->message && !strstr (lerror->message, "no such function")) {
-			g_propagate_error (error, lerror);
-			return FALSE;
-		}
-		else
-			return TRUE;
-	}
+	if (!tmpmodel)
+		return FALSE;
 		
 	nrows = gda_data_model_get_n_rows (tmpmodel);
 	for (i = 0; i < nrows; i++) {
@@ -1246,7 +1240,6 @@ fill_constraints_tab_model (GdaConnection *cnc, SqliteConnectionData *cdata, Gda
 	const gchar *schema_name;
 	gint i;
 	GdaStatement *stmt;
-	GError *lerror = NULL;
 
 	schema_name = g_value_get_string (p_table_schema);
 
@@ -1259,19 +1252,13 @@ fill_constraints_tab_model (GdaConnection *cnc, SqliteConnectionData *cdata, Gda
 				G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_NONE};
 	gboolean has_pk = FALSE;
 
-	stmt = get_statement (I_PRAGMA_TABLE_INFO, schema_name, g_value_get_string (p_table_name), NULL);
+	stmt = get_statement (I_PRAGMA_TABLE_INFO, schema_name, g_value_get_string (p_table_name), error);
 	tmpmodel = gda_connection_statement_execute_select_full (cnc, stmt, pragma_set, 
 								 GDA_STATEMENT_MODEL_RANDOM_ACCESS, 
-								 pk_col_types, &lerror);
+								 pk_col_types, error);
 	g_object_unref (stmt);
-	if (!tmpmodel) {
-		if (lerror && lerror->message && !strstr (lerror->message, "no such function")) {
-			g_propagate_error (error, lerror);
-			return FALSE;
-		}
-		else
-			return TRUE;
-	}
+	if (!tmpmodel)
+		return FALSE;
 		
 	nrows = gda_data_model_get_n_rows (tmpmodel);
 	for (i = 0; i < nrows; i++) {
@@ -1815,20 +1802,13 @@ fill_key_columns_model (GdaConnection *cnc, SqliteConnectionData *cdata, GdaData
 		GType pk_col_types[] = {G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, 
 					G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_NONE};
 		gint ord_pos = 1;
-		GError *lerror = NULL;
-		stmt = get_statement (I_PRAGMA_TABLE_INFO, schema_name, g_value_get_string (p_table_name), NULL);
+		stmt = get_statement (I_PRAGMA_TABLE_INFO, schema_name, g_value_get_string (p_table_name), error);
 		tmpmodel = gda_connection_statement_execute_select_full (cnc, stmt, pragma_set, 
 									 GDA_STATEMENT_MODEL_RANDOM_ACCESS, 
-									 pk_col_types, &lerror);
+									 pk_col_types, error);
 		g_object_unref (stmt);
-		if (!tmpmodel) {
-			if (lerror && lerror->message && !strstr (lerror->message, "no such function")) {
-				g_propagate_error (error, lerror);
-				return FALSE;
-			}
-			else
-				return TRUE;
-		}
+		if (!tmpmodel)
+			return FALSE;
 		
 		nrows = gda_data_model_get_n_rows (tmpmodel);
 		for (i = 0; i < nrows; i++) {
