@@ -166,7 +166,6 @@ typedef GdaDataModel *(*GdaVconnectionDataModelCreateFModelFunc) (GdaVconnection
  * Note that if specifying a @create_filtered_model_func, you should also specifiy a @create_filter_func
  * function which is actually responsible for analysing the optimization.
  */
-
 struct _GdaVconnectionDataModelSpec {
 	GdaDataModel                             *data_model;
 	GdaVconnectionDataModelCreateColumnsFunc  create_columns_func;
@@ -189,8 +188,33 @@ struct _GdaVconnectionDataModelClass {
 							  const gchar *table_name);
 	void                          (*vtable_dropped) (GdaVconnectionDataModel *cnc,
 							    const gchar *table_name);
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_gda_reserved1) (void);
+	void (*_gda_reserved2) (void);
 };
 
+/**
+ * SECTION:gda-vconnection-data-model
+ * @short_description: Virtual connection based on a list of GdaDataModel
+ * @title: GdaVconnectionDataModel
+ * @stability: Stable
+ * @see_also: The #GdaVproviderDataModel provider to use to create such connection objects.
+ *
+ * The #GdaVconnectionDataModel is a virtual connection in which #GdaDataModel data models can be added
+ * or removed, each representing a table in the connection, the gda_vconnection_data_model_add_model()
+ * and gda_vconnection_data_model_remove() methods.
+ *
+ * Furthermore it is possible to declare tables without any associated data model yet,
+ * the real data model being automatically created when the
+ * table's data is needed. This allows more dynamic table's contents and filtering optimizations.
+ * See the gda_vconnection_data_model_add() and gda_vconnection_data_model_remove() methods. The
+ * filtering optimizations are based on SQLite's virtual table optimisations see
+ * <ulink url="http://www.sqlite.org/cvstrac/wiki?p=VirtualTableBestIndexMethod">SQLite's documentation</ulink>
+ * for some background information.
+ */
+
 GType               gda_vconnection_data_model_get_type  (void) G_GNUC_CONST;
 
 gboolean            gda_vconnection_data_model_add       (GdaVconnectionDataModel *cnc, GdaVconnectionDataModelSpec *spec, 
