@@ -14,7 +14,7 @@ JniWrapperMethod *GdaJResultSet__fillNextRow = NULL;
 JNIEXPORT void
 JNICALL Java_GdaJResultSet_initIDs (JNIEnv *env, jclass klass)
 {
-	gint i;
+	gsize i;
 	typedef struct {
 		const gchar       *name;
 		const gchar       *sig;
