@@ -1,21 +1,23 @@
-/*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* GDA provider
+ * Copyright (C) 2009 - 2010 The GNOME Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <stdio.h>
@@ -720,7 +722,7 @@ gda_web_provider_begin_transaction (GdaServerProvider *provider, GdaConnection *
 
 	/* prepare XML command */
 	xmlDocPtr doc;
-	xmlNodePtr root;
+	xmlNodePtr root, cmdnode;
 	gchar *token;
 	doc = xmlNewDoc (BAD_CAST "1.0");
 	root = xmlNewNode (NULL, BAD_CAST "request");
@@ -728,7 +730,7 @@ gda_web_provider_begin_transaction (GdaServerProvider *provider, GdaConnection *
 	token = _gda_web_compute_token (cdata);
 	xmlNewChild (root, NULL, BAD_CAST "token", BAD_CAST token);
 	g_free (token);
-	xmlNewChild (root, NULL, BAD_CAST "cmd", BAD_CAST "BEGIN");
+	cmdnode = xmlNewChild (root, NULL, BAD_CAST "cmd", BAD_CAST "BEGIN");
 
 	/* send command */
 	xmlChar *cmde;
@@ -780,7 +782,7 @@ gda_web_provider_commit_transaction (GdaServerProvider *provider, GdaConnection
 
 	/* prepare XML command */
 	xmlDocPtr doc;
-	xmlNodePtr root;
+	xmlNodePtr root, cmdnode;
 	gchar *token;
 	doc = xmlNewDoc (BAD_CAST "1.0");
 	root = xmlNewNode (NULL, BAD_CAST "request");
@@ -788,7 +790,7 @@ gda_web_provider_commit_transaction (GdaServerProvider *provider, GdaConnection
 	token = _gda_web_compute_token (cdata);
 	xmlNewChild (root, NULL, BAD_CAST "token", BAD_CAST token);
 	g_free (token);
-	xmlNewChild (root, NULL, BAD_CAST "cmd", BAD_CAST "COMMIT");
+	cmdnode = xmlNewChild (root, NULL, BAD_CAST "cmd", BAD_CAST "COMMIT");
 
 	/* send command */
 	xmlChar *cmde;
@@ -840,7 +842,7 @@ gda_web_provider_rollback_transaction (GdaServerProvider *provider, GdaConnectio
 
 	/* prepare XML command */
 	xmlDocPtr doc;
-	xmlNodePtr root;
+	xmlNodePtr root, cmdnode;
 	gchar *token;
 	doc = xmlNewDoc (BAD_CAST "1.0");
 	root = xmlNewNode (NULL, BAD_CAST "request");
@@ -848,7 +850,7 @@ gda_web_provider_rollback_transaction (GdaServerProvider *provider, GdaConnectio
 	token = _gda_web_compute_token (cdata);
 	xmlNewChild (root, NULL, BAD_CAST "token", BAD_CAST token);
 	g_free (token);
-	xmlNewChild (root, NULL, BAD_CAST "cmd", BAD_CAST "ROLLBACK");
+	cmdnode = xmlNewChild (root, NULL, BAD_CAST "cmd", BAD_CAST "ROLLBACK");
 
 	/* send command */
 	xmlChar *cmde;
@@ -1173,8 +1175,6 @@ gtype_to_webtype (GType type)
                 return "text";
         if (type == G_TYPE_INT)
                 return "integer";
-        if (type == GDA_TYPE_LIST)
-                return "text";
         if (type == GDA_TYPE_NUMERIC)
                 return "decimal";
         if (type == G_TYPE_FLOAT)
@@ -1485,15 +1485,7 @@ gda_web_provider_statement_execute (GdaServerProvider *provider, GdaConnection *
 			}
 		}
 		if (!h) {
-			if (allow_noparam) {
-                                /* bind param to NULL */
-				node = xmlNewChild (argsnode, NULL, BAD_CAST "arg", NULL);
-				xmlSetProp (node, BAD_CAST "type", BAD_CAST "NULL");
-                                empty_rs = TRUE;
-                                continue;
-			}
-			else {
-
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1502,16 +1494,18 @@ gda_web_provider_statement_execute (GdaServerProvider *provider, GdaConnection *
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-                        }
-		}
-		if (!gda_holder_is_valid (h)) {
-			if (allow_noparam) {
+			}
+			else {
                                 /* bind param to NULL */
+				node = xmlNewChild (argsnode, NULL, BAD_CAST "arg", NULL);
 				xmlSetProp (node, BAD_CAST "type", BAD_CAST "NULL");
                                 empty_rs = TRUE;
                                 continue;
-			}
-			else {
+                        }
+
+		}
+		if (!gda_holder_is_valid (h)) {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1520,6 +1514,12 @@ gda_web_provider_statement_execute (GdaServerProvider *provider, GdaConnection *
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
+			}
+			else {
+                                /* bind param to NULL */
+				xmlSetProp (node, BAD_CAST "type", BAD_CAST "NULL");
+                                empty_rs = TRUE;
+                                continue;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1559,49 +1559,12 @@ gda_web_provider_statement_execute (GdaServerProvider *provider, GdaConnection *
 
 		/* actual binding using the C API, for parameter at position @i */
 		const GValue *value = gda_holder_get_value (h);
-		if (!value || gda_value_is_null (value)) {
-			GdaStatement *rstmt;
-			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
-				gchar *tmp;
-				tmp = gda_value_stringify (value);
-				node = xmlNewTextChild (argsnode, NULL, BAD_CAST "arg", BAD_CAST tmp);
-				g_free (tmp);
-				xmlSetProp (node, BAD_CAST "type",
-					    BAD_CAST gtype_to_webtype (gda_holder_get_g_type (h)));
-			}
-			else if (!rstmt)
-				return NULL;
-			else {
-				GObject *obj;
-				g_object_unref (ps);
-				xmlFreeDoc (doc);
-				obj = gda_web_provider_statement_execute (provider, cnc,
-									  rstmt, params,
-									  model_usage,
-									  col_types,
-									  last_inserted_row,
-									  task_id, async_cb,
-									  cb_data, error);
-				g_object_unref (rstmt);
-				if (GDA_IS_DATA_SELECT (obj)) {
-					GdaPStmt *pstmt;
-					g_object_get (obj, "prepared-stmt", &pstmt, NULL);
-					if (pstmt) {
-						gda_pstmt_set_gda_statement (pstmt, stmt);
-						g_object_unref (pstmt);
-					}
-				}
-				return obj;
-			}
-		}
-		else {
-			gchar *tmp;
-			tmp = gda_value_stringify (value);
-			node = xmlNewTextChild (argsnode, NULL, BAD_CAST "arg", BAD_CAST tmp);
-			g_free (tmp);
-			xmlSetProp (node, BAD_CAST "type",
-				    BAD_CAST gtype_to_webtype (gda_holder_get_g_type (h)));
-		}
+		gchar *tmp;
+		tmp = gda_value_stringify (value);
+		node = xmlNewTextChild (argsnode, NULL, BAD_CAST "arg", BAD_CAST tmp);
+		g_free (tmp);
+		xmlSetProp (node, BAD_CAST "type",
+			    BAD_CAST gtype_to_webtype (gda_holder_get_g_type (h)));
 	}
 		
 	if (event) {
