@@ -13,8 +13,6 @@ main (int argc, char **argv)
 {
 	int number_failed = 0;
 
-	/* set up test environment */
-	g_setenv ("GDA_TOP_BUILD_DIR", TOP_BUILD_DIR, 0);
 	gda_init ();
 
 	pinfo = gda_config_get_provider_info (PROVIDER);
@@ -27,7 +25,6 @@ main (int argc, char **argv)
 	number_failed = prov_test_common_setup ();
 
 	if (cnc) {
-		number_failed += prov_test_common_create_tables_sql ();
 		number_failed += prov_test_common_check_meta ();
 		number_failed += prov_test_common_clean ();
 	}
