@@ -1,8 +1,8 @@
 /* 
  * Copyright (C) 2009 - 2011 Vivien Malerba
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -305,6 +305,13 @@ sub_thread_open_cnc (AuthData *ad, GError **error)
 						       GDA_CONNECTION_OPTIONS_THREAD_SAFE |
 						       GDA_CONNECTION_OPTIONS_AUTO_META_DATA,
 						       error);
+#ifdef HAVE_LDAP
+	if (cnc && GDA_IS_LDAP_CONNECTION (cnc)) {
+		/* force classes init */
+		GdaLdapClass *lcl;
+		lcl = gda_ldap_get_class_info (GDA_LDAP_CONNECTION (cnc), "top");
+	}
+#endif
 	return cnc;
 #else
 	sleep (5);
@@ -368,6 +375,12 @@ update_dialog_focus (AuthDialog *dialog)
 	}
 }
 
+static void
+auth_form_activated_cb (G_GNUC_UNUSED GdauiBasicForm *form, AuthDialog *dialog)
+{
+	gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+}
+
 /**
  * auth_dialog_add_cnc_string
  */
@@ -398,7 +411,7 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
                 e2 = gda_rfc1738_encode (file);
                 g_free (path);
                 g_free (file);
-                real_cnc_string = g_strdup_printf ("%s://DB_DIR=%s;LOAD_GDA_FUNCTIONS=TRUE;DB_NAME=%s", pname, e1, e2);
+                real_cnc_string = g_strdup_printf ("%s://DB_DIR=%s;EXTRA_FUNCTIONS=TRUE;DB_NAME=%s", pname, e1, e2);
                 g_free (e1);
                 g_free (e2);
                 gda_connection_string_split (real_cnc_string, &real_cnc, &real_provider, &user, &pass);
@@ -420,6 +433,7 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
 	AuthData *ad;
 	ad = g_new0 (AuthData, 1);
 	ad->wrapper = gda_thread_wrapper_new ();
+	/*g_print ("Login dialog: new thread wrapper %p\n", ad->wrapper);*/
 	ad->ext.cnc_string = g_strdup (cnc_string);
 	ad->auth_string = NULL;
 	info = gda_config_get_dsn_info (real_cnc);
@@ -487,8 +501,8 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
 
                 set = gda_set_copy (pinfo->auth_params);
                 ad->auth_widget = gdaui_basic_form_new (set);
-                /*g_signal_connect (G_OBJECT (ad->auth_widget), "holder-changed",
-		  G_CALLBACK (auth_form_changed), dialog);*/
+                g_signal_connect (G_OBJECT (ad->auth_widget), "activated",
+				  G_CALLBACK (auth_form_activated_cb), dialog);
                 g_object_unref (set);
 
 		/* add widget */
@@ -621,7 +635,7 @@ auth_dialog_run (AuthDialog *dialog)
 						const GValue *cvalue = NULL;
 						if (gda_holder_is_valid (holder))
 							cvalue = gda_holder_get_value (holder);
-						if (cvalue) {
+						if (cvalue && (G_VALUE_TYPE (cvalue) != GDA_TYPE_NULL)) {
 							gchar *r1, *r2;
 							r1 = gda_value_stringify (cvalue);
 							r2 = gda_rfc1738_encode (r1);
