@@ -1,8 +1,8 @@
 /* 
  * Copyright (C) 2009 - 2011 Vivien Malerba
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -17,13 +17,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-
 #ifndef __BROWSER_CONNECTION_H_
 #define __BROWSER_CONNECTION_H_
 
 #include <libgda/libgda.h>
 #include "browser-favorites.h"
 #include "decl.h"
+#include "support.h"
+#ifdef HAVE_LDAP
+#include <libgda/sqlite/virtual/gda-ldap-connection.h>
+#endif
 
 G_BEGIN_DECLS
 
@@ -57,6 +60,19 @@ struct _BrowserConnectionClass
 							      const gchar *attr_name, const gchar *value);
 };
 
+/**
+ * SECTION:browser-connection
+ * @short_description: An opened connection
+ * @title: BrowserConnection
+ * @stability: Stable
+ * @see_also:
+ *
+ * The #BrowserConnection object wraps a #GdaConnection with some
+ * additionnal features. The wrapped #GdaConnection is only accessible from within
+ * the #BrowserConnection object, so to use a connection, you have to use the
+ * #BrowserConnection's methods.
+ */
+
 GType               browser_connection_get_type               (void) G_GNUC_CONST;
 
 BrowserConnection  *browser_connection_new                    (GdaConnection *cnc);
@@ -64,6 +80,7 @@ const gchar        *browser_connection_get_name               (BrowserConnection
 const GdaDsnInfo   *browser_connection_get_information        (BrowserConnection *bcnc);
 
 gboolean            browser_connection_is_busy                (BrowserConnection *bcnc, gchar **out_reason);
+gboolean            browser_connection_is_virtual             (BrowserConnection *bcnc);
 void                browser_connection_update_meta_data       (BrowserConnection *bcnc);
 void                browser_connection_meta_data_changed      (BrowserConnection *bcnc);
 GdaMetaStruct      *browser_connection_get_meta_struct        (BrowserConnection *bcnc);
@@ -75,6 +92,24 @@ BrowserFavorites   *browser_connection_get_favorites          (BrowserConnection
 gchar             **browser_connection_get_completions        (BrowserConnection *bcnc, const gchar *sql,
 							       gint start, gint end);
 
+/**
+ * BrowserConnectionJobCallback:
+ * @bcnc: the #BrowserConnection
+ * @out_result: the execution result
+ * @data: a pointer passed when calling the execution function such as browser_connection_ldap_describe_entry()
+ * @error: the error returned, if any
+ *
+ * Callback function called when a job (not a statement execution job) is finished.
+ * the out_result is not used by the BrowserConnection anymore after this function has been
+ * called, so you need to keep it or free it.
+ *
+ * @error should not be modified.
+ */
+typedef void (*BrowserConnectionJobCallback) (BrowserConnection *bcnc,
+					      gpointer out_result, gpointer data, GError *error);
+#define BROWSER_CONNECTION_JOB_CALLBACK(x) ((BrowserConnectionJobCallback)(x))
+void                browser_connection_job_cancel             (BrowserConnection *bcnc, guint job_id);
+
 /*
  * statements's manipulations
  */
@@ -161,6 +196,49 @@ void                 browser_connection_define_ui_plugins_for_stmt (BrowserConne
 void                 browser_connection_keep_variables (BrowserConnection *bcnc, GdaSet *set);
 void                 browser_connection_load_variables (BrowserConnection *bcnc, GdaSet *set);
 
+/*
+ * LDAP
+ */
+gboolean             browser_connection_is_ldap        (BrowserConnection *bcnc);
+#ifdef HAVE_LDAP
+const         gchar *browser_connection_ldap_get_base_dn (BrowserConnection *bcnc);
+guint                browser_connection_ldap_search (BrowserConnection *bcnc,
+						     const gchar *base_dn, const gchar *filter,
+						     const gchar *attributes, GdaLdapSearchScope scope,
+						     BrowserConnectionJobCallback callback,
+						     gpointer cb_data, GError **error);
+guint                browser_connection_ldap_describe_entry (BrowserConnection *bcnc, const gchar *dn,
+							     BrowserConnectionJobCallback callback,
+							     gpointer cb_data, GError **error);
+guint                browser_connection_ldap_get_entry_children (BrowserConnection *bcnc, const gchar *dn,
+								 gchar **attributes,
+								 BrowserConnectionJobCallback callback,
+								 gpointer cb_data, GError **error);
+guint                browser_connection_ldap_icon_for_dn (BrowserConnection *bcnc, const gchar *dn,
+							  BrowserConnectionJobCallback callback,
+							  gpointer cb_data, GError **error);
+GdkPixbuf           *browser_connection_ldap_icon_for_class (GdaLdapAttribute *objectclass);
+gboolean             browser_connection_describe_table  (BrowserConnection *bcnc, const gchar *table_name,
+							 const gchar **out_base_dn, const gchar **out_filter,
+							 const gchar **out_attributes,
+							 GdaLdapSearchScope *out_scope, GError **error);
+
+GdaLdapClass        *browser_connection_get_class_info (BrowserConnection *bcnc, const gchar *classname);
+const GSList        *browser_connection_get_top_classes (BrowserConnection *bcnc);
+
+gboolean             browser_connection_declare_table   (BrowserConnection *bcnc,
+                                                         const gchar *table_name,
+                                                         const gchar *base_dn,
+                                                         const gchar *filter,
+                                                         const gchar *attributes,
+                                                         GdaLdapSearchScope scope,
+                                                         GError **error);
+gboolean             browser_connection_undeclare_table   (BrowserConnection *bcnc,
+							   const gchar *table_name,
+							   GError **error);
+
+#endif
+
 G_END_DECLS
 
 #endif
