@@ -1,8 +1,8 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -92,6 +92,7 @@ struct _BrowserWindowPrivate {
 	gboolean           toolbar_shown;
 	gboolean           cursor_in_toolbar;
 	GtkWidget         *spinner;
+	guint              spinner_timer;
 	GtkUIManager      *ui_manager;
 	GtkActionGroup    *agroup;
 	GtkActionGroup    *perspectives_actions;
@@ -179,6 +180,7 @@ browser_window_init (BrowserWindow *bwin)
 	bwin->priv->fullscreen = FALSE;
 	bwin->priv->fullscreen_motion_sig_id = 0;
 	bwin->priv->fullscreen_timer_id = 0;
+	bwin->priv->spinner_timer = 0;
 }
 
 static void
@@ -192,6 +194,11 @@ browser_window_dispose (GObject *object)
 	bwin = BROWSER_WINDOW (object);
 	if (bwin->priv) {
 		GSList *connections, *list;
+
+		if (bwin->priv->spinner_timer) {
+			g_source_remove (bwin->priv->spinner_timer);
+			bwin->priv->spinner_timer = 0;
+		}
 		connections = browser_core_get_connections ();
 		for (list = connections; list; list = list->next)
 			connection_removed_cb (browser_core_get(), BROWSER_CONNECTION (list->data), bwin);
@@ -343,10 +350,9 @@ static const gchar *ui_actions_info =
         "      <menuitem name='HelpAbout' action= 'HelpAbout'/>"
         "    </menu>"
         "  </menubar>"
-        "  <toolbar  name='ToolBar'>"
+        "  <toolbar name='ToolBar'>"
         "    <toolitem action='WindowClose'/>"
         "    <toolitem action='WindowFullScreen'/>"
-	"    <separator/>"
         "    <toolitem action='TransactionBegin'/>"
         "    <toolitem action='TransactionCommit'/>"
         "    <toolitem action='TransactionRollback'/>"
@@ -374,7 +380,8 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 {
 	BrowserWindow *bwin;
 	const gchar *cncname;
-	gchar *str;
+	const GdaDsnInfo *dsn;
+	GString *title;
 
 	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
 
@@ -383,12 +390,19 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	g_signal_connect (bcnc, "transaction-status-changed",
 			  G_CALLBACK (transaction_status_changed_cb), bwin);
 
+	dsn = browser_connection_get_information (bcnc);
 	cncname = browser_connection_get_name (bcnc);
-	if (!cncname)
-		cncname = _("unnamed");
-	str = g_strdup_printf (_("Connection: %s"), cncname);
-	gtk_window_set_title (GTK_WINDOW (bwin), str);
-	g_free (str);
+	title = g_string_new (_("Connection"));
+	g_string_append (title, " ");
+	g_string_append_printf (title, "'%s'", cncname ? cncname : _("unnamed"));
+	if (dsn) {
+		if (dsn->name)
+			g_string_append_printf (title, ", %s '%s'", _("data source"), dsn->name);
+		if (dsn->provider)
+			g_string_append_printf (title, " (%s)", dsn->provider);
+	}
+	gtk_window_set_title (GTK_WINDOW (bwin), title->str);
+	g_string_free (title, TRUE);
 	gtk_window_set_default_size ((GtkWindow*) bwin, 900, 650);
 	g_signal_connect (G_OBJECT (bwin), "delete-event",
                           G_CALLBACK (delete_event), bwin);
@@ -421,6 +435,15 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	bwin->priv->agroup = group;
         gtk_action_group_add_actions (group, ui_actions, G_N_ELEMENTS (ui_actions), bwin);
 	gtk_action_group_add_toggle_actions (group, ui_toggle_actions, G_N_ELEMENTS (ui_toggle_actions), bwin);
+	if (browser_connection_is_virtual (bwin->priv->bcnc)) {
+		GtkAction *action;
+		action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionBegin");
+		gtk_action_set_visible (action, FALSE);
+		action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionCommit");
+		gtk_action_set_visible (action, FALSE);
+		action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionRollback");
+		gtk_action_set_visible (action, FALSE);
+	}
 	transaction_status_changed_cb (bwin->priv->bcnc, bwin);
 
         ui = gtk_ui_manager_new ();
@@ -549,8 +572,11 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	for (plist = browser_core_get_factories (); plist; plist = plist->next) {
 		GtkAction *action;
 		const gchar *name;
-		
+
 		name = BROWSER_PERSPECTIVE_FACTORY (plist->data)->perspective_name;
+		if (!strcmp (name, _("LDAP browser")) && !browser_connection_is_ldap (bcnc))
+			continue;
+
 		action = GTK_ACTION (gtk_radio_action_new (name, name, NULL, NULL, FALSE));
 
 		if (!active_action && 
@@ -664,42 +690,58 @@ perspective_toggle_cb (GtkRadioAction *action, GtkRadioAction *current, BrowserW
 		g_object_unref (actions);
 }
 
+static gboolean
+spinner_stop_timer (BrowserWindow *bwin)
+{
+	browser_spinner_stop (BROWSER_SPINNER (bwin->priv->spinner));
+	bwin->priv->spinner_timer = 0;
+	return FALSE; /* remove timer */
+}
+
 static void
 connection_busy_cb (BrowserConnection *bcnc, gboolean is_busy, gchar *reason, BrowserWindow *bwin)
 {
-	if (is_busy) {
-		browser_spinner_start (BROWSER_SPINNER (bwin->priv->spinner));
-		gtk_widget_set_tooltip_text (bwin->priv->spinner, reason);
-		gtk_statusbar_push (GTK_STATUSBAR (bwin->priv->statusbar),
-				    bwin->priv->cnc_statusbar_context,
-				    reason);
-	}
-	else {
-		browser_spinner_stop (BROWSER_SPINNER (bwin->priv->spinner));
-		gtk_widget_set_tooltip_text (bwin->priv->spinner, NULL);
-		gtk_statusbar_pop (GTK_STATUSBAR (bwin->priv->statusbar),
-				   bwin->priv->cnc_statusbar_context);
-	}
-
 	GtkAction *action;
-	action = gtk_action_group_get_action (bwin->priv->agroup, "WindowNew");
-	gtk_action_set_sensitive (action, !is_busy);
-	action = gtk_action_group_get_action (bwin->priv->agroup, "ConnectionMetaSync");
-	gtk_action_set_sensitive (action, !is_busy);
+	if (bcnc == bwin->priv->bcnc) {
+		/* @bcbc is @bwin's own connection */
+		if (bwin->priv->spinner_timer) {
+			g_source_remove (bwin->priv->spinner_timer);
+			bwin->priv->spinner_timer = 0;
+		}
+		if (is_busy) {
+			browser_spinner_start (BROWSER_SPINNER (bwin->priv->spinner));
+			gtk_widget_set_tooltip_text (bwin->priv->spinner, reason);
+			gtk_statusbar_push (GTK_STATUSBAR (bwin->priv->statusbar),
+					    bwin->priv->cnc_statusbar_context,
+					    reason);
+		}
+		else {
+			bwin->priv->spinner_timer = g_timeout_add (300,
+						    (GSourceFunc) spinner_stop_timer, bwin);
+			gtk_widget_set_tooltip_text (bwin->priv->spinner, NULL);
+			gtk_statusbar_pop (GTK_STATUSBAR (bwin->priv->statusbar),
+					   bwin->priv->cnc_statusbar_context);
+		}
 
-	gboolean bsens = FALSE, csens = FALSE;
-	if (!is_busy) {
-		if (browser_connection_get_transaction_status (bcnc))
-			csens = TRUE;
-		else
-			bsens = TRUE;
+		gboolean bsens = FALSE, csens = FALSE;
+		if (!is_busy) {
+			if (browser_connection_get_transaction_status (bcnc))
+				csens = TRUE;
+			else
+				bsens = TRUE;
+		}
+		action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionBegin");
+		gtk_action_set_sensitive (action, bsens);
+		action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionCommit");
+		gtk_action_set_sensitive (action, csens);
+		action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionRollback");
+		gtk_action_set_sensitive (action, csens);
+
+		action = gtk_action_group_get_action (bwin->priv->agroup, "WindowNew");
+		gtk_action_set_sensitive (action, !is_busy);
+		action = gtk_action_group_get_action (bwin->priv->agroup, "ConnectionMetaSync");
+		gtk_action_set_sensitive (action, !is_busy);
 	}
-	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionBegin");
-	gtk_action_set_sensitive (action, bsens);
-	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionCommit");
-	gtk_action_set_sensitive (action, csens);
-	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionRollback");
-	gtk_action_set_sensitive (action, csens);	
 
 	const gchar *cncname;
 	cncname = browser_connection_get_name (bcnc);
@@ -936,8 +978,8 @@ toolbar_hide_timeout_cb (BrowserWindow *bwin)
 		return TRUE;
 }
 
-#define BWIN_WINDOW_FULLSCREEN_POPUP_THRESHOLD 5
-#define BWIN_WINDOW_FULLSCREEN_POPUP_TIMER 1
+#define BWIN_WINDOW_FULLSCREEN_POPUP_THRESHOLD 15
+#define BWIN_WINDOW_FULLSCREEN_POPUP_TIMER 5
 
 static gboolean
 fullscreen_motion_notify_cb (GtkWidget *widget, GdkEventMotion *event, G_GNUC_UNUSED gpointer user_data)
