@@ -1,5 +1,4 @@
-/* ui-formgrid.c
- *
+/*
  * Copyright (C) 2010 - 2011 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
@@ -28,6 +27,9 @@
 #include "../support.h"
 #include "../browser-window.h"
 #include <libgda/gda-data-model-extra.h>
+#ifdef HAVE_LDAP
+#include "../ldap-browser/ldap-browser-perspective.h"
+#endif
 
 static void ui_formgrid_class_init (UiFormGridClass * class);
 static void ui_formgrid_init (UiFormGrid *wid);
@@ -56,6 +58,7 @@ struct _UiFormGridPriv
 	GdauiDataProxyInfoFlag flags;
 	
 	BrowserConnection *bcnc;
+	gboolean     scroll_form;
 };
 
 /* get a pointer to the parents to be able to call their destructor */
@@ -67,6 +70,7 @@ enum {
 	PROP_RAW_GRID,
 	PROP_RAW_FORM,
 	PROP_INFO,
+	PROP_SCROLL_FORM
 };
 
 GType
@@ -118,6 +122,10 @@ ui_formgrid_class_init (UiFormGridClass *class)
                                          g_param_spec_object ("widget_info", NULL, NULL, 
 							      GDAUI_TYPE_DATA_PROXY_INFO,
 							      G_PARAM_READABLE));
+	g_object_class_install_property (object_class, PROP_SCROLL_FORM,
+					 g_param_spec_boolean ("scroll-form", NULL, NULL,
+							       FALSE,
+							       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
@@ -142,8 +150,28 @@ static void
 ui_formgrid_show (GtkWidget *widget)
 {
 	UiFormGrid *formgrid;
-	((GtkWidgetClass *)parent_class)->show (widget);
 	formgrid = UI_FORMGRID (widget);
+
+	/* finalize packing */
+	if (formgrid->priv->scroll_form) {
+		GtkWidget *sw, *vp;
+		sw = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+						GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_NONE);
+		vp = gtk_viewport_new (NULL, NULL);
+		gtk_container_add (GTK_CONTAINER (sw), vp);
+		gtk_viewport_set_shadow_type (GTK_VIEWPORT (vp), GTK_SHADOW_NONE);
+		gtk_container_add (GTK_CONTAINER (vp), formgrid->priv->raw_form);
+		gtk_notebook_append_page (GTK_NOTEBOOK (formgrid->priv->nb), sw, NULL);
+		gtk_widget_show_all (sw);
+	}
+	else {
+		gtk_notebook_append_page (GTK_NOTEBOOK (formgrid->priv->nb), formgrid->priv->raw_form, NULL);
+		gtk_widget_show (formgrid->priv->raw_form);
+	}
+
+	((GtkWidgetClass *)parent_class)->show (widget);
 	if (! formgrid->priv->autoupdate_possible)
 		gtk_widget_hide (formgrid->priv->autoupdate_toggle);
 }
@@ -165,6 +193,7 @@ ui_formgrid_init (UiFormGrid *formgrid)
 	formgrid->priv->bcnc = NULL;
 	formgrid->priv->autoupdate = TRUE;
 	formgrid->priv->autoupdate_possible = FALSE;
+	formgrid->priv->scroll_form = FALSE;
 
 	/* notebook */
 	formgrid->priv->nb = gtk_notebook_new ();
@@ -190,8 +219,6 @@ ui_formgrid_init (UiFormGrid *formgrid)
 	/* form on the 2nd page of the notebook */
 	formgrid->priv->raw_form = gdaui_raw_form_new (NULL);
 	gdaui_data_proxy_column_show_actions (GDAUI_DATA_PROXY (formgrid->priv->raw_form), -1, FALSE);
-	gtk_notebook_append_page (GTK_NOTEBOOK (formgrid->priv->nb), formgrid->priv->raw_form, NULL);
-        gtk_widget_show (formgrid->priv->raw_form);
 	g_signal_connect (formgrid->priv->raw_form, "populate-popup",
 			  G_CALLBACK (form_grid_populate_popup_cb), formgrid);
 
@@ -259,7 +286,8 @@ form_grid_toggled_cb (GtkToggleButton *button, UiFormGrid *formgrid)
 		gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_pixbuf (pixbuf));
 
 		iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (formgrid->priv->raw_grid));
-		row = gda_data_model_iter_get_row (iter);
+		if (iter)
+			row = gda_data_model_iter_get_row (iter);
 		iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (formgrid->priv->raw_form));
 	}
 	else {
@@ -277,11 +305,13 @@ form_grid_toggled_cb (GtkToggleButton *button, UiFormGrid *formgrid)
 		gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_pixbuf (pixbuf));
 
 		iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (formgrid->priv->raw_form));
-		row = gda_data_model_iter_get_row (iter);
+		if (iter)
+			row = gda_data_model_iter_get_row (iter);
 		iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (formgrid->priv->raw_grid));
 	}
 
-	gda_data_model_iter_move_to_row (iter, row >= 0 ? row : 0);
+	if (iter)
+		gda_data_model_iter_move_to_row (iter, row >= 0 ? row : 0);
 }
 
 static BrowserConnection *
@@ -301,13 +331,15 @@ get_browser_connection (UiFormGrid *formgrid)
 
 
 static void execute_action_mitem_cb (GtkMenuItem *menuitem, UiFormGrid *formgrid);
+#ifdef HAVE_LDAP
+static void ldap_view_dn_mitem_cb (GtkMenuItem *menuitem, UiFormGrid *formgrid);
+#endif
 
 static void
 form_grid_populate_popup_cb (G_GNUC_UNUSED GtkWidget *wid, GtkMenu *menu, UiFormGrid *formgrid)
 {
 	/* add actions to execute to menu */
 	GdaDataModelIter *iter;
-	GSList *actions_list, *list;
 	BrowserConnection *bcnc = NULL;
 
 	bcnc = get_browser_connection (formgrid);
@@ -315,30 +347,71 @@ form_grid_populate_popup_cb (G_GNUC_UNUSED GtkWidget *wid, GtkMenu *menu, UiForm
 		return;
 	
 	iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (formgrid->priv->raw_grid));
+
+	/* actions */
+	GSList *actions_list, *list;
 	actions_list = browser_favorites_get_actions (browser_connection_get_favorites (bcnc),
 						      bcnc, GDA_SET (iter));
-	if (! actions_list)
-		return;
-
-	GtkWidget *mitem, *submenu;
-	mitem = gtk_menu_item_new_with_label (_("Execute action"));
-	gtk_widget_show (mitem);
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), mitem);
-
-	submenu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), submenu);
-	for (list = actions_list; list; list = list->next) {
-		BrowserFavoriteAction *act = (BrowserFavoriteAction*) list->data;
-		mitem = gtk_menu_item_new_with_label (act->name);
+	if (actions_list) {
+		GtkWidget *mitem, *submenu;
+		mitem = gtk_menu_item_new_with_label (_("Execute action"));
 		gtk_widget_show (mitem);
-		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), mitem);
-		g_object_set_data_full (G_OBJECT (mitem), "action", act,
-					(GDestroyNotify) browser_favorites_free_action);
-		g_signal_connect (mitem, "activate",
-				  G_CALLBACK (execute_action_mitem_cb), formgrid);
+		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), mitem);
+		
+		submenu = gtk_menu_new ();
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), submenu);
+		for (list = actions_list; list; list = list->next) {
+			BrowserFavoriteAction *act = (BrowserFavoriteAction*) list->data;
+			mitem = gtk_menu_item_new_with_label (act->name);
+			gtk_widget_show (mitem);
+			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), mitem);
+			g_object_set_data_full (G_OBJECT (mitem), "action", act,
+						(GDestroyNotify) browser_favorites_free_action);
+			g_signal_connect (mitem, "activate",
+					  G_CALLBACK (execute_action_mitem_cb), formgrid);
+		}
+		g_slist_free (actions_list);
 	}
 
-	g_slist_free (actions_list);
+#ifdef HAVE_LDAP
+	/* LDAP specific */
+	if (browser_connection_is_ldap (bcnc)) {
+		GdaHolder *dnh;
+		dnh = gda_set_get_holder (GDA_SET (iter), "dn");
+		if (dnh) {
+			const GValue *cvalue;
+			cvalue = gda_holder_get_value (GDA_HOLDER (dnh));
+			if (!cvalue && (G_VALUE_TYPE (cvalue) != G_TYPE_STRING))
+				dnh = NULL;
+		}
+		if (!dnh) {
+			GSList *list;
+			for (list = GDA_SET (iter)->holders; list; list = list->next) {
+				const GValue *cvalue;
+				cvalue = gda_holder_get_value (GDA_HOLDER (list->data));
+				if (cvalue && (G_VALUE_TYPE (cvalue) == G_TYPE_STRING) &&
+				    gda_ldap_is_dn (g_value_get_string (cvalue))) {
+					dnh = GDA_HOLDER (list->data);
+					break;
+				}
+			}
+		}
+
+		if (dnh) {
+			const GValue *cvalue;
+			cvalue = gda_holder_get_value (dnh);
+
+			GtkWidget *mitem;
+			mitem = gtk_menu_item_new_with_label (_("View LDAP entry's details"));
+			gtk_widget_show (mitem);
+			gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), mitem);
+			g_object_set_data_full (G_OBJECT (mitem), "dn",
+						g_value_dup_string (cvalue), g_free);
+			g_signal_connect (mitem, "activate",
+					  G_CALLBACK (ldap_view_dn_mitem_cb), formgrid);
+		}
+	}
+#endif
 }
 
 typedef struct {
@@ -476,7 +549,7 @@ statement_executed_cb (G_GNUC_UNUSED BrowserConnection *bcnc,
 		gtk_misc_set_alignment (GTK_MISC (label), 0., 0.);
 		gtk_box_pack_start (GTK_BOX (dcontents), label, FALSE, FALSE, 5);
 		
-		fg = ui_formgrid_new (GDA_DATA_MODEL (out_result),
+		fg = ui_formgrid_new (GDA_DATA_MODEL (out_result), TRUE,
 				      GDAUI_DATA_PROXY_INFO_CURRENT_ROW);
 		ui_formgrid_set_connection (UI_FORMGRID (fg), aed->bcnc);
 
@@ -570,23 +643,40 @@ execute_action_mitem_cb (GtkMenuItem *menuitem, UiFormGrid *formgrid)
 	}
 }
 
+#ifdef HAVE_LDAP
+static void ldap_view_dn_mitem_cb (GtkMenuItem *menuitem, UiFormGrid *formgrid)
+{
+	const gchar *dn;
+	BrowserWindow *bwin;
+        BrowserPerspective *pers;
+
+	dn = g_object_get_data (G_OBJECT (menuitem), "dn");
+        bwin = (BrowserWindow*) gtk_widget_get_toplevel ((GtkWidget*) formgrid);
+        pers = browser_window_change_perspective (bwin, _("LDAP browser"));
+
+	ldap_browser_perspective_display_ldap_entry (LDAP_BROWSER_PERSPECTIVE (pers), dn);
+}
+#endif
+
 /**
  * ui_formgrid_new
  * @model: a #GdaDataModel
+ * @scroll_form: set to %TRUE to wrap the embedded form in a scrolled window
+ * @flags: the #GdauiDataProxyInfoFlag, specifying what to display in the new widget
  *
  * Creates a new #UiFormGrid widget suitable to display the data in @model
  *
  *  Returns: the new widget
  */
 GtkWidget *
-ui_formgrid_new (GdaDataModel *model, GdauiDataProxyInfoFlag flags)
+ui_formgrid_new (GdaDataModel *model, gboolean scroll_form, GdauiDataProxyInfoFlag flags)
 {
 	UiFormGrid *formgrid;
 	GdaDataProxy *proxy;
 
 	g_return_val_if_fail (!model || GDA_IS_DATA_MODEL (model), NULL);
 
-	formgrid = (UiFormGrid *) g_object_new (UI_TYPE_FORMGRID, NULL);
+	formgrid = (UiFormGrid *) g_object_new (UI_TYPE_FORMGRID, "scroll-form", scroll_form, NULL);
 	formgrid->priv->flags = flags;
 
 	/* a raw form and a raw grid for the same proxy */
@@ -600,7 +690,8 @@ ui_formgrid_new (GdaDataModel *model, GdauiDataProxyInfoFlag flags)
 		      GDAUI_DATA_PROXY_INFO_CHUNCK_CHANGE_BUTTONS, NULL);
 
 	/* no more than 300 rows at a time */
-	gda_data_proxy_set_sample_size (proxy, 300);
+	if (model)
+		gda_data_proxy_set_sample_size (proxy, 300);
 
 	return (GtkWidget *) formgrid;
 }
@@ -688,7 +779,9 @@ ui_formgrid_set_property (GObject *object,
 	formgrid = UI_FORMGRID (object);
 	
 	switch (param_id) {
-		
+	case PROP_SCROLL_FORM:
+		formgrid->priv->scroll_form = g_value_get_boolean (value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
