@@ -4,8 +4,8 @@
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -948,7 +948,7 @@ data_console_page_get_actions_group (BrowserPage *page)
 	DataConsole *dconsole;
 	dconsole = DATA_CONSOLE (page);
 	if (! dconsole->priv->agroup) {
-		dconsole->priv->agroup = gtk_action_group_new ("QueryExecConsoleActions");
+		dconsole->priv->agroup = gtk_action_group_new ("DataManagerConsoleActions");
 		gtk_action_group_set_translation_domain (dconsole->priv->agroup, GETTEXT_PACKAGE);
 		gtk_action_group_add_toggle_actions (dconsole->priv->agroup,
 						     ui_actions, G_N_ELEMENTS (ui_actions), page);
