@@ -1,19 +1,23 @@
 /*
- * Copyright (C) 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2010 The GNOME Foundation
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This program is distributed in the hope that it will be useful,
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __DATA_CONSOLE_H__
@@ -49,7 +53,6 @@ GtkWidget               *data_console_new             (BrowserConnection *bcnc);
 GtkWidget               *data_console_new_with_fav_id (BrowserConnection *bcnc, gint fav_id);
 void                     data_console_set_text        (DataConsole *console, const gchar *text);
 gchar                   *data_console_get_text        (DataConsole *console);
-gboolean                 data_console_is_unused       (DataConsole *console);
 void                     data_console_execute         (DataConsole *console);
 void                     data_console_set_fav_id      (DataConsole *dconsole, gint fav_id,
 						       GError **error);
