@@ -23,7 +23,6 @@
 #include <glib/gi18n-lib.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
 #include "entry-properties.h"
 #include "marshal.h"
 #include <time.h>
@@ -447,8 +446,8 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, EntryProperties *epro
 	GtkTextBuffer *buffer;
 	
 	switch (event->keyval) {
-	case GDK_Return: 
-	case GDK_KP_Enter:
+	case GDK_KEY_Return: 
+	case GDK_KEY_KP_Enter:
 		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
 		gtk_text_buffer_get_iter_at_mark (buffer, &iter, 
 						  gtk_text_buffer_get_insert (buffer));
