@@ -12,7 +12,7 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
@@ -41,6 +41,9 @@
 #include "schema-browser/perspective-main.h"
 #include "query-exec/perspective-main.h"
 #include "data-manager/perspective-main.h"
+#ifdef HAVE_LDAP
+#include "ldap-browser/perspective-main.h"
+#endif
 /* #include "dummy-perspective/perspective-main.h" */
 
 extern BrowserCoreInitFactories browser_core_init_factories;
@@ -52,6 +55,9 @@ main_browser_core_init_factories (void)
 	factories = g_slist_append (factories, schema_browser_perspective_get_factory ());
 	factories = g_slist_append (factories, query_exec_perspective_get_factory ());
 	factories = g_slist_append (factories, data_manager_perspective_get_factory ());
+#ifdef HAVE_LDAP
+	factories = g_slist_append (factories, ldap_browser_perspective_get_factory ());
+#endif
 	/* factories = g_slist_append (factories, dummy_perspective_get_factory ()); */
 	return factories;
 }
@@ -100,6 +106,7 @@ main (int argc, char *argv[])
 
 	context = g_option_context_new (_("[DSN|connection string]..."));
         g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
         g_option_context_set_ignore_unknown_options (context, TRUE);
         if (!g_option_context_parse (context, &argc, &argv, &error)) {
                 g_fprintf  (stderr, "Can't parse arguments: %s\n", error->message);
@@ -131,9 +138,20 @@ main (int argc, char *argv[])
 	if (list_configs) {
 		gda_init ();
 		setlocale (LC_ALL, "");
-		GdaDataModel *model = config_info_list_all_dsn ();
-		output_data_model (model);
-		g_object_unref (model);
+		GdaDataModel *model;
+		if (argc == 2)
+			model = config_info_detail_dsn (argv[1], &error);
+		else
+			model = config_info_list_all_dsn ();
+		if (model) {
+			output_data_model (model);
+			g_object_unref (model);
+		}
+		else {
+			g_print (_("Error: %s\n"),
+				 error && error->message ? error->message : _("No detail"));
+			g_clear_error (&error);
+		}
 		return 0;
 	}
 	if (list_data_files) {
@@ -204,6 +222,7 @@ main (int argc, char *argv[])
 					 error && error->message ? error->message : _("No detail"));
 				break;
 			}
+			config_info_modify_argv (argv[i]);
 		}
 		
 		if (dialog) {
@@ -233,7 +252,7 @@ main (int argc, char *argv[])
 					}
 				}
 			}
-			gtk_widget_destroy (dialog);
+			gtk_widget_destroy ((GtkWidget*) dialog);
 		}
 	}
 	
