@@ -4,8 +4,8 @@
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -82,7 +82,7 @@ mgr_columns_class_init (MgrColumnsClass *klass)
 }
 
 static void
-mgr_columns_init (MgrColumns *mgr, MgrColumnsClass *klass)
+mgr_columns_init (MgrColumns *mgr, G_GNUC_UNUSED MgrColumnsClass *klass)
 {
 	mgr->priv = g_new0 (MgrColumnsPriv, 1);
 }
@@ -136,7 +136,8 @@ mgr_columns_get_type (void)
                         NULL,
                         sizeof (MgrColumns),
                         0,
-                        (GInstanceInitFunc) mgr_columns_init
+                        (GInstanceInitFunc) mgr_columns_init,
+			0
                 };
 
                 g_static_mutex_lock (&registering);
@@ -164,6 +165,9 @@ mgr_columns_set_property (GObject *object,
 				g_object_ref (mgr->priv->bcnc);
 			
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
                 }
         }
 }
@@ -182,6 +186,9 @@ mgr_columns_get_property (GObject *object,
 		case PROP_BROWSER_CNC:
 			g_value_set_object (value, mgr->priv->bcnc);
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
                 }
         }
 }
